#!/usr/bin/perl
# /bin/perl
# /usr/contrib/bin/perl
#
# This script tests CKBRIEF. It includes two routines: test_data and run_test.
# test_data is called once to generate all needed kernels; run_test is
# called once for each test case and reports to the screen.
#
$version = "1.1.0 -- March 31, 2009 -- BVS/NAIF";

#
# Version 1.1.0 -- March 31, 2009 -- BVS/NAIF
#
#    Updated short error messages to include only 'SPICE(*)'.
#
# Version 1.0.0 -- October 12, 2008 -- BVS/NAIF
#
#    Initial version.
#
#---------------------------------------------------------------------------
# Begin of configuration parameter section. See descritions below.
#---------------------------------------------------------------------------

#
# For UNIX.
#
$ckbrief       = "./ckbrief";
$msopck        = "./msopck";
$tobin         = "./tobin";
$maxtocompare  = "";
$shortonly     = "no";
$checkcount    = "yes";
$qt            = "'";

#
# For Windows
#
$ckbrief       = ".\\ckbrief";
$msopck        = ".\\msopck";
$tobin         = ".\\tobin";
$maxtocompare  = "77";
$shortonly     = "yes";
$checkcount    = "no";
$qt            = "";

#
# For CYGWIN.
#
#$ckbrief       = "ckbrief";
#$msopck        = "msopck";
#$tobin         = "tobin";
#$maxtocompare  = "";
#$shortonly     = "no";
#$checkcount    = "yes";
#$qt            = "'";

#
# $ckbrief          Executables invoked by and other files used by the
# $msopck           script.
# $tobin
#
# $reporttype       Information types that test cases should report
#                   (space delimited list including any combination of
#                   these words "command output expvalues")
#
# $maxtocompare     The number of characters of each expected value to
#                   be used in comparison. To use all characters it
#                   must be set to "".
#
# $shortonly        Flag indicating whether for failure-type cases only
#                   short error message should be checked ("yes" or
#                   "no").
#
# $checkcount       Flag indicating whether the output line count
#                   should be checked ("yes" or "no").
#
# $logname          Log file name (to be passed as argument to
# $logopt           run_test) and log file option (to be included in
#                   the command line passed to run_test).
#
# $qt               Quote used to quote command line keys and values
#                   that cannot be specified unquoted (for example []
#                   must be passed as '[]' to Unix shells)
#
$reporttype = " ";

$logname = "";
$logopt  = "";
#$logname = "tmp.log";
#$logopt  = "-l tmp.log ";

#---------------------------------------------------------------------------
# End of configuration parameter section.
#---------------------------------------------------------------------------

#
# These counters are global variables incremented by run_test routine. (Yuck!)
#
$counttotal = 0;
$countpass  = 0;
$countfail  = 0;

#
# Generate test report banner. Include OS name and date.
#
$seconds = time;
($sec,$min,$hours,$mday,$mon,$year,$wday,$yday) = gmtime($seconds);

print  "\n";
print  "CKBRIEF Test Suite, Version -- $version\n";
print  "\n";
printf "--- DATE: %4d-%02d-%02d %02d:%02d:%02d GMT\n",
       $year+1900, $mon+1, $mday, $hours, $min, $sec;
print  "--- OS:   $^O\n";

#
# Run CKBRIEF without command line arguments and dump its output to
# the screen to remove any ambiguity of what version is tested.
#

$result = `$ckbrief 2>&1`;
print "\n";
print "Testing the following CKBRIEF:\n";
print "\n";
print "--- $ckbrief\n";
print "\n";
print "$result";

#
# Prepare test data
#
print "\n";
print "Preparing test data ...\n";
print "\n";
&test_data( $msopck, $tobin, "make" );

#
# Run tests.
#
print "\n";
print "Executing tests ...\n";
print "\n";

#
# Tests in this block test exceptions.
#

#
# The following exceptions can be caused only by buffer overflows and
# are not covered due to impracticality of pushing the large limits set
# for buffers:
#
#    ?/?

#
# Exceptions yet to cover: command line syntax, other?
#

#
# Test exceptions first.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non-existing file is given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_ck_2.bc',
  15,
"SPICE(FILENOTFOUND)",
"The kernel file 'ckbrief_ck_2.bc' does not exist.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF --> GETFAT"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non-existing file is given in the list file',
  'failure',
  $ckbrief,
  '-f ckbrief_list_bad_nonexisting.txt',
  15,
"SPICE(FILENOTFOUND)",
"The kernel file 'ckbrief_ck.bc' does not exist.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF --> GETFAT"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non-existing list file after -f',
  'failure',
  $ckbrief,
  '-f boo',
  15,
"SPICE(FILEOPENFAILED)",
"Could not open boo.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF --> RDNBL --> RDTEXT"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'transfer format CK is given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_ck_cov1_id1.xc',
  16,
"SPICE(TRANSFERFORMAT)",
"Kernel 'ckbrief_ck_cov1_id1.xc' is in transfer format. It must be converted to",
"binary format to be summarized using CKBRIEF.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'SPK is given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_spk.bsp',
  16,
"SPICE(SPKFILE)",
"Kernel 'ckbrief_spk.bsp' is a binary SPK and, therefore, cannot be summarized",
"using CKBRIEF. Use BRIEF or SPACIT to summarize this file.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'SPK is given in list file',
  'failure',
  $ckbrief,
  '-f ckbrief_list_bad_spk.txt',
  16,
"SPICE(SPKFILE)",
"Kernel 'ckbrief_spk.bsp' is a binary SPK and, therefore, cannot be summarized",
"using CKBRIEF. Use BRIEF or SPACIT to summarize this file.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'binary PCK is given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_pck.bpc',
  16,
"SPICE(PCKFILE)",
"Kernel 'ckbrief_pck.bpc' is a binary PCK and, therefore, cannot be summarized",
"using CKBRIEF. Use BRIEF or SPACIT to summarize this file.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'EK is given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_ek.bes',
  16,
"SPICE(EKFILE)",
"Kernel 'ckbrief_ek.bes' is a binary EK and, therefore, cannot be summarized",
"using BRIEF. Use SPACIT or INSPEKT to summarize this file.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'transfer EK file is given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_ek.xes',
  16,
"SPICE(TRANSFERFORMAT)",
"Kernel 'ckbrief_ek.xes' is in transfer format. It must be converted to binary",
"format to be summarized using CKBRIEF.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'DEC file is given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_dec.xdc',
  16,
"SPICE(TRANSFERFORMAT)",
"Kernel 'ckbrief_dec.xdc' is in transfer format. It must be converted to binary",
"format to be summarized using CKBRIEF.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non-EK DAS given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_dsk.bds',
  16,
"SPICE(BADARCHITECTURE)",
"Kernel 'ckbrief_dsk.bds' is not a binary CK and, therefore, cannot be",
"summarized using CKBRIEF. It is a 'DAS/DSK' file.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non-SPK/PCK/CK DAF given on the command line',
  'failure',
  $ckbrief,
  'ckbrief_uk.bu',
  16,
"SPICE(BADARCHITECTURE)",
"Kernel 'ckbrief_uk.bu' is not a binary CK and, therefore, cannot be summarized",
"using CKBRIEF. It is a 'DAF/UK' file.",
"A traceback follows.  The name of the highest level module is first.",
"CKBRIEF"
);

#
# Test good cases.
#

#
# Test usage, help, and version displays.
#
@toolversion = (
"CKBRIEF -- Version 5.0.0, February 11, 2009 -- Toolkit Version N????"
);

@toolusage = (
"   CKBRIEF is a command-line utility program that displays a summary for",
"   one or more binary CK files. The program usage is:",
"      \% ckbrief [-options] file [file ...]",
"   The most useful options are shown below. For the complete set of",
"   options, run CKBRIEF with the -h option. The order of options is not",
"   significant. The option keys must be lowercase as shown below.",
"      -dump        display interpolation intervals",
"      -rel         display relative-to frames (may need FK)",
"      -n           display frames associated with CK IDs (may need FK)",
"      -t           display summary in a tabular format",
"      -utc         display times in UTC calendar date format (needs LSK&SCLK)",
"      -utcdoy      display times in UTC day-of-year format (needs LSK&SCLK)",
"      -sclk        display times as SCLK strings (needs SCLK)",
"   LSK and SCLK files must be provided on the command line to display times",
"   in UTC, ET, or SCLK formats. FK file(s) must be provided on the command",
"   line to display names of any frames that are not built into the Toolkit."
);

@toolhelp = (
"   CKBRIEF is a command line program that displays a summary of the",
"   contents and time coverage for one or more binary CK files. The program",
"   displays a summary for each CK file listed on the command line, in a",
"   list file, and/or a meta-kernel. It can display coverage boundaries as",
"   ephemeris time (ET) in calendar format, as UTC time in",
"   ``year-month-day'' or ``day-of-year'' format, or as on-board clock",
"   (SCLK) time in string or encoded format. It can display the summary in a",
"   variety of formats, with or without showing the names of the frames",
"   associated with spacecraft or structure IDs or the names/IDs of the",
"   frames with respect to which orientation is provided.",
"   The program usage is:",
"      ckbrief [-options] file [file ...]",
"   where [file]s are binary CK files and text kernels needed to support",
"   time conversion (LSK and SCLKs), or containing frame definitions (FKs),",
"   provided in any order. The options are:",
"      -dump        display interpolation intervals boundaries",
"      -nm          display segment boundaries",
"      -rel         display relative-to frames",
"      -n           display frames associated with structure IDs",
"      -t           display summary in a tabular format",
"      -g           display summary grouped by coverage",
"      -utc         display times in UTC calendar date format",
"      -utcdoy      display times in UTC day-of-year format",
"      -sclk        display times as SCLK strings",
"      -dpsclk      display times as SCLK ticks",
"      [ID]         display summary for structure with [ID]",
"      -f [list]    summarize kernels listed in the [list] file",
"      -h           display help",
"      -v           display version",
"   The options can be provided in any order and can appear before, after,",
"   or intermixed with file names. The case of option keys is significant:",
"   they must be lowercase as shown above. While any option can be provided",
"   together with any other option or a combination of options, some options",
"   will override others."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'usage display, no command line arguments',
  'success',
  $ckbrief,
  '',
  24,
  @toolversion,
  @toolusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'help display, -h',
  'success',
  $ckbrief,
  '-h',
  50,
  @toolversion,
  @toolhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'version display, -v',
  'success',
  $ckbrief,
  '-v',
  3,
  @toolversion
);

#
# Test more good cases.
#

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one file on command line',
  'success',
  $ckbrief,
  'ckbrief_ck_cov1_id1.bc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'many files on command line',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_sclk_id3.tsc ckbrief_ck_cov1_id1.bc ckbrief_ck_cov1_id2.bc ckbrief_ck_cov1_id3.bc',
  27,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov1_id2.bc",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov1_id3.bc",
"Object:  -85100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

#&run_test (
#  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
#  'one-line with EOF in the list file',
#  'success',
#  $ckbrief,
#  '-f ckbrief_list_bad_eof.txt',
#  6,
#"No CK files were provided -- no summary will be displayed.",
#"Run CKBRIEF without command line options to see program usage."
#);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one file in list file (-f)',
  'success',
  $ckbrief,
  '-f ckbrief_list_one_ck.txt',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'many files in list file (-f)',
  'success',
  $ckbrief,
  '-f ckbrief_list_many_cks.txt',
  20,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"Summary for: ckbrief_ck_cov31_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'many files on command line, many files in list file (-f)',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -f ckbrief_list_many_cks.txt',
  28,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y",
"Summary for: ckbrief_ck_cov31_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one file in one meta-kernel',
  'success',
  $ckbrief,
  'ckbrief_mk_one_ck.tm',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'many files in one meta-kernel',
  'success',
  $ckbrief,
  'ckbrief_mk_many_cks.tm',
  19,
"Summary for: ckbrief_ck_cov1_id2.bc",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov1_id3.bc",
"Object:  -85100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'many files in many meta-kernels',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_mk_one_ck.tm ckbrief_mk_many_cks.tm',
  27,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov1_id2.bc",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov1_id3.bc",
"Object:  -85100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'list file specified twice',
  'success',
  $ckbrief,
  '-f ckbrief_list_one_ck.txt -f ckbrief_list_many_cks.txt',
  20,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"Summary for: ckbrief_ck_cov31_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f at the end without list file',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -f',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'too many objects filters on the command line',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -1 -2 -3 -4 -5 -6 -7 -8 -9 -10 -11 -12 -13 -14 -15 -16 -17 -18 -19 -20 -21 -22 -23 -24 -25 -26 -27 -28 -29 -30 -31 -32 -33 -34 -35 -36 -37 -38 -39 -40 -41 -42 -43 -44 -45 -46 -47 -48 -49 -50 -51 -52 -53 -54 -55 -56 -57 -58 -59 -60 -61 -62 -63 -64 -65 -66 -67 -68 -69 -70 -71 -72 -73 -74 -75 -76 -77 -78 -79 -80 -81 -82 -83 -84 -85 -86 -87 -88 -89 -90 -91 -92 -93 -94 -95 -96 -97 -98 -99 -100 -101',
  11,
" Object number",
"-101",
" doesn't fit into the buffer",
" which can hold no more than",
" MAXUSE elements.",
"No data for specified objects in ckbrief_ck_cov1_id1.bc"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unrecognized option',
  'success',
  $ckbrief,
  '-boo',
  53,
"'-boo' is not a recognized option.",
  @toolhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-v ignored when files are provided on the command line',
  'success',
  $ckbrief,
  '-v ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-v ignored when -h is provided',
  'success',
  $ckbrief,
  '-v -h',
  50,
  @toolhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-v ignored when -f is provided ',
  'success',
  $ckbrief,
  '-v -f ckbrief_list_one_ck.txt',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'list file with many files on one line',
  'success',
  $ckbrief,
  '-f ckbrief_list_mixed_one_line.txt',
  20,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y",
"Summary for: ckbrief_ck_cov31_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'list file with many lines with one file per line',
  'success',
  $ckbrief,
  '-f ckbrief_list_mixed_one_per_line.txt',
  20,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y",
"Summary for: ckbrief_ck_cov31_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'list file with many lines each with many files',
  'success',
  $ckbrief,
  '-f ckbrief_list_mixed_many_per_line.txt',
  20,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y",
"Summary for: ckbrief_ck_cov31_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'files on command line, no CKs',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc',
  6,
"No CK files were provided -- no summary will be displayed.",
"Run CKBRIEF without command line options to see program usage."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'files in list file, no CKs',
  'success',
  $ckbrief,
  '-f ckbrief_list_no_cks.txt',
  6,
"No CK files were provided -- no summary will be displayed.",
"Run CKBRIEF without command line options to see program usage."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'files in meta-kernels, no CKs',
  'success',
  $ckbrief,
  'ckbrief_mk_no_ck.tm',
  6,
"No CK files were provided -- no summary will be displayed.",
"Run CKBRIEF without command line options to see program usage."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one object filter, display summary',
  'success',
  $ckbrief,
  '-84100 ckbrief_mk.tm ckbrief_ck_cov12_id12.bc',
  11,
"Summary for: ckbrief_ck_cov12_id12.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one object filter, no result',
  'success',
  $ckbrief,
  '-84111 ckbrief_mk.tm ckbrief_ck_cov12_id12.bc',
  6,
"No data for specified objects in ckbrief_ck_cov12_id12.bc"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'many object filters, display summary',
  'success',
  $ckbrief,
  '-84001 -84100 ckbrief_mk.tm ckbrief_ck_cov13133_id11223.bc',
  18,
"Summary for: ckbrief_ck_cov13133_id11223.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'many object filters, no result',
  'success',
  $ckbrief,
  '-84111 -84222 ckbrief_mk.tm ckbrief_ck_cov13133_id11223.bc',
  6,
"No data for specified objects in ckbrief_ck_cov13133_id11223.bc"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -nm is ignored',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -nm',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -g is ignored',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -g',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, object filters are ignored',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -84111',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump for type 1 CK',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_type1.bc',
  10,
"Summary for: ckbrief_ck_type1.bc",
"Segment No.: 1",
"This segment is a type 1 segment for which interpolation is not supported."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump for type 2 CK',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_type2.bc',
  14,
"Summary for: ckbrief_ck_type2.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:41.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:21.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump for type 3 CK',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_type3.bc',
  14,
"Summary for: ckbrief_ck_type3.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:42.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:22.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump for type 5 CK',
  'success',
  $ckbrief,
  '-dump -dpsclk ckbrief_ck_type5.bc',
  13,
"Summary for: ckbrief_ck_type5.bc",
"Segment No.: 1",
"Object:  -41001",
"  Interval Begin TICKS     Interval End TICKS       AV",
"  ------------------------ ------------------------ ---",
"   7282058810254.           7282067723150.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, one segment',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, many segments',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov13133_id11223.bc',
  46,
"Summary for: ckbrief_ck_cov13133_id11223.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y",
"Segment No.: 2",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:29:10.000 Y",
"  2007-DEC-04 00:30:00.000 2007-DEC-04 00:30:00.000 Y",
"Segment No.: 3",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y",
"Segment No.: 4",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:29:10.000 Y",
"  2007-DEC-04 00:30:00.000 2007-DEC-04 00:30:00.000 Y",
"Segment No.: 5",
"Object:  -85100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, one file',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id2.bc',
  14,
"Summary for: ckbrief_ck_cov1_id2.bc",
"Segment No.: 1",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, many files',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc ckbrief_ck_cov1_id2.bc ckbrief_ck_cov1_id3.bc',
  36,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov1_id2.bc",
"Segment No.: 1",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y",
"Summary for: ckbrief_ck_cov1_id3.bc",
"Segment No.: 1",
"Object:  -85100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -rel, resolved frame',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -rel',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"  ------------------------ ------------------------ --- -----------------",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y   PHX_LL",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -rel, unresolved frame',
  'success',
  $ckbrief,
  '-dump ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -rel',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"  ------------------------ ------------------------ --- -----------------",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y   -84903",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y   -84903"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -n, resolved frame',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -n',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Frame:   PHX_PAYLOAD",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -n, unresolved frame',
  'success',
  $ckbrief,
  '-dump ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -n',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Frame:   NO FRAME FOR -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -n, -rel',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -rel -n',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Frame:   PHX_PAYLOAD",
"  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"  ------------------------ ------------------------ --- -----------------",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y   PHX_LL",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, default time',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"  2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -sclk',
  'success',
  $ckbrief,
  '-dump ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -sclk',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin SCLK      Interval End SCLK        AV",
"  ------------------------ ------------------------ ---",
"  1/0250000000.000         1/0250000000.000         Y",
"  1/0250000100.000         1/0250000100.000         Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -dpsclk',
  'success',
  $ckbrief,
  '-dump ckbrief_ck_cov1_id1.bc -dpsclk',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin TICKS     Interval End TICKS       AV",
"  ------------------------ ------------------------ ---",
"    250000000000.            250000000000.          Y",
"    250000100000.            250000100000.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -utc',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -utc',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin UTC       Interval End UTC         AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:25:34.816 2007-DEC-04 00:25:34.816 Y",
"  2007-DEC-04 00:27:14.816 2007-DEC-04 00:27:14.816 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -utcdoy',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -utcdoy',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin UTC/DOY   Interval End UTC/DOY     AV",
"  ------------------------ ------------------------ ---",
"  2007-338 // 00:25:34.816 2007-338 // 00:25:34.816 Y",
"  2007-338 // 00:27:14.816 2007-338 // 00:27:14.816 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, default time, no SCLK',
  'success',
  $ckbrief,
  '-dump ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -sclk, no SCLK',
  'success',
  $ckbrief,
  '-dump ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -sclk',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin SCLK      Interval End SCLK        AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -dpsclk, no SCLK',
  'success',
  $ckbrief,
  '-dump ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -dpsclk',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin TICKS     Interval End TICKS       AV",
"  ------------------------ ------------------------ ---",
"    250000000000.            250000000000.          Y",
"    250000100000.            250000100000.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -utc, no SCLK',
  'success',
  $ckbrief,
  '-dump ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -utc',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin UTC       Interval End UTC         AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -utcdoy, no SCLK',
  'success',
  $ckbrief,
  '-dump ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -utcdoy',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin UTC/DOY   Interval End UTC/DOY     AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, default time, no LSK',
  'success',
  $ckbrief,
  '-dump ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -sclk, no LSK',
  'success',
  $ckbrief,
  '-dump ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -sclk',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin SCLK      Interval End SCLK        AV",
"  ------------------------ ------------------------ ---",
"  1/0250000000.000         1/0250000000.000         Y",
"  1/0250000100.000         1/0250000100.000         Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -dpsclk, no LSK',
  'success',
  $ckbrief,
  '-dump ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -dpsclk',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin TICKS     Interval End TICKS       AV",
"  ------------------------ ------------------------ ---",
"    250000000000.            250000000000.          Y",
"    250000100000.            250000100000.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -utc, no LSK',
  'success',
  $ckbrief,
  '-dump ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -utc',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin UTC       Interval End UTC         AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -utcdoy, no LSK',
  'success',
  $ckbrief,
  '-dump ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -utcdoy',
  14,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Object:  -84100",
"  Interval Begin UTC/DOY   Interval End UTC/DOY     AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -t',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t',
  13,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"-84100   2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -t, -sclk',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -sclk',
  13,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Objects  Interval Begin SCLK      Interval End SCLK        AV",
"-------- ------------------------ ------------------------ ---",
"-84100   1/0250000000.000         1/0250000000.000         Y",
"-84100   1/0250000100.000         1/0250000100.000         Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -t, -n',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -n',
  13,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Frames                     Interval Begin ET        Interval End ET          AV",
"-------------------------- ------------------------ ------------------------ ---",
"PHX_PAYLOAD                2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y",
"PHX_PAYLOAD                2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -t, -rel',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -rel',
  13,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Objects  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"-------- ------------------------ ------------------------ --- -----------------",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y   PHX_LL",
"-84100   2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-dump, -t, -n, -rel',
  'success',
  $ckbrief,
  '-dump ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -n -rel',
  13,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Segment No.: 1",
"Frames                     Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"-------------------------- ------------------------ ------------------------ --- -----------------",
"PHX_PAYLOAD                2007-DEC-04 00:26:40.000 2007-DEC-04 00:26:40.000 Y   PHX_LL",
"PHX_PAYLOAD                2007-DEC-04 00:28:20.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, one segment',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, non-overlaping segments, ordered coverages',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov13_id11.bc',
  12,
"Summary for: ckbrief_ck_cov13_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, non-overlaping segments, out-of-order coverages',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov31_id11.bc',
  12,
"Summary for: ckbrief_ck_cov31_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, overlaping segments, ordered coverages',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov12_id11.bc',
  11,
"Summary for: ckbrief_ck_cov12_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, overlaping segments, out-of-order coverages',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov21_id11.bc',
  11,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, overlaping segments, different frames',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov21_id11_diff_frames.bc -rel',
  11,
"Summary for: ckbrief_ck_cov21_id11_diff_frames.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"  ------------------------ ------------------------ --- -----------------",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y   MIXED"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, overlaping segments, different AV flags',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov21_id11_diff_av.bc',
  11,
"Summary for: ckbrief_ck_cov21_id11_diff_av.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 *"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, one id, overlaping segments, -nm',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov21_id11.bc -nm',
  12,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:27:55.000 2007-DEC-04 00:29:35.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, many ids, one segment per id, same coverage',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov11_id12.bc',
  16,
"Summary for: ckbrief_ck_cov11_id12.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, many ids, one segment per id, different coverage',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov12_id12.bc',
  16,
"Summary for: ckbrief_ck_cov12_id12.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:27:55.000 2007-DEC-04 00:29:35.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, many ids, many non-overlaping segments per id, ordered coverages',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1313_id1122.bc',
  18,
"Summary for: ckbrief_ck_cov1313_id1122.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, many ids, many non-overlaping segments per id, out-of-order coverages',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov3311_id2121.bc',
  18,
"Summary for: ckbrief_ck_cov3311_id2121.bc",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, many ids, many overlaping segments per id',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1212_id1122.bc',
  16,
"Summary for: ckbrief_ck_cov1212_id1122.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, many ids, many overlaping segments per id, -nm',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1212_id1122.bc -nm',
  18,
"Summary for: ckbrief_ck_cov1212_id1122.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:27:55.000 2007-DEC-04 00:29:35.000 Y",
"Object:  -84001",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"  2007-DEC-04 00:27:55.000 2007-DEC-04 00:29:35.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -rel, resolved frame',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -rel',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"  ------------------------ ------------------------ --- -----------------",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -rel, unresolved frame',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -rel',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"  ------------------------ ------------------------ --- -----------------",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y   -84903"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -n, resolved frame',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -n',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Frame:   PHX_PAYLOAD",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -n, unresolved frame',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -n',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Frame:   NO FRAME FOR -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -n, -rel',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -rel -n',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Frame:   PHX_PAYLOAD",
"  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"  ------------------------ ------------------------ --- -----------------",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, default time',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -sclk',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -sclk',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin SCLK      Interval End SCLK        AV",
"  ------------------------ ------------------------ ---",
"  1/0250000000.000         1/0250000100.000         Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -dpsclk',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -dpsclk',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin TICKS     Interval End TICKS       AV",
"  ------------------------ ------------------------ ---",
"    250000000000.            250000100000.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -utc',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -utc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin UTC       Interval End UTC         AV",
"  ------------------------ ------------------------ ---",
"  2007-DEC-04 00:25:34.816 2007-DEC-04 00:27:14.816 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -utcdoy',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -utcdoy',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin UTC/DOY   Interval End UTC/DOY     AV",
"  ------------------------ ------------------------ ---",
"  2007-338 // 00:25:34.816 2007-338 // 00:27:14.816 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, default time, no SCLK',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -sclk, no SCLK',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -sclk',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin SCLK      Interval End SCLK        AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -dpsclk, no SCLK',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -dpsclk',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin TICKS     Interval End TICKS       AV",
"  ------------------------ ------------------------ ---",
"    250000000000.            250000100000.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -utc, no SCLK',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -utc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin UTC       Interval End UTC         AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -utcdoy, no SCLK',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -utcdoy',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin UTC/DOY   Interval End UTC/DOY     AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, default time, no LSK',
  'success',
  $ckbrief,
  'ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin ET        Interval End ET          AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -sclk, no LSK',
  'success',
  $ckbrief,
  'ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -sclk',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin SCLK      Interval End SCLK        AV",
"  ------------------------ ------------------------ ---",
"  1/0250000000.000         1/0250000100.000         Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -dpsclk, no LSK',
  'success',
  $ckbrief,
  'ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -dpsclk',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin TICKS     Interval End TICKS       AV",
"  ------------------------ ------------------------ ---",
"    250000000000.            250000100000.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -utc, no LSK',
  'success',
  $ckbrief,
  'ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -utc',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin UTC       Interval End UTC         AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -utcdoy, no LSK',
  'success',
  $ckbrief,
  'ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -utcdoy',
  11,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Object:  -84100",
"  Interval Begin UTC/DOY   Interval End UTC/DOY     AV",
"  ------------------------ ------------------------ ---",
"  NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -g is ignored',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -g',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -n, resolved frame',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -n',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Frames                     Interval Begin ET        Interval End ET          AV",
"-------------------------- ------------------------ ------------------------ ---",
"PHX_PAYLOAD                2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -n, unresolved frame',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -t -n',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Frames                     Interval Begin ET        Interval End ET          AV",
"-------------------------- ------------------------ ------------------------ ---",
"NO FRAME FOR -84100        2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -rel, resolved frame',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -rel',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"-------- ------------------------ ------------------------ --- -----------------",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -rel, unresolved frame',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -t -rel',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"-------- ------------------------ ------------------------ --- -----------------",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y   -84903"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -rel, different frames',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov21_id11_diff_frames.bc -t -rel',
  10,
"Summary for: ckbrief_ck_cov21_id11_diff_frames.bc",
"Objects  Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"-------- ------------------------ ------------------------ --- -----------------",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 Y   MIXED"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -n, -rel',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -n -rel',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Frames                     Interval Begin ET        Interval End ET          AV  Relative to FRAME",
"-------------------------- ------------------------ ------------------------ --- -----------------",
"PHX_PAYLOAD                2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y   PHX_LL"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, different AVs',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov21_id11_diff_av.bc -t',
  10,
"Summary for: ckbrief_ck_cov21_id11_diff_av.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:29:35.000 *"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, default time',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -sclk',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -sclk',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin SCLK      Interval End SCLK        AV",
"-------- ------------------------ ------------------------ ---",
"-84100   1/0250000000.000         1/0250000100.000         Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -dpsclk',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -dpsclk',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin TICKS     Interval End TICKS       AV",
"-------- ------------------------ ------------------------ ---",
"-84100     250000000000.            250000100000.          Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -utc',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -utc',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin UTC       Interval End UTC         AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:25:34.816 2007-DEC-04 00:27:14.816 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, -utcdoy',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -t -utcdoy',
  10,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Objects  Interval Begin UTC/DOY   Interval End UTC/DOY     AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-338 // 00:25:34.816 2007-338 // 00:27:14.816 Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, many ids, same coverage',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov11_id12.bc -t',
  11,
"Summary for: ckbrief_ck_cov11_id12.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:26:40.000 2007-DEC-04 00:28:20.000 Y",
"-84001      -- same --               -- same --            Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, many ids, same coverage, no SCLK',
  'success',
  $ckbrief,
  'ckbrief_lsk.tls ckbrief_ck_cov11_id12.bc -t',
  11,
"Summary for: ckbrief_ck_cov11_id12.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"-84001   NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, many ids, same coverage, no LSK',
  'success',
  $ckbrief,
  'ckbrief_sclk.tsc ckbrief_ck_cov11_id12.bc -t',
  11,
"Summary for: ckbrief_ck_cov11_id12.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y",
"-84001   NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default output, -t, many ids, same coverage, no SCLK for some',
  'success',
  $ckbrief,
  'ckbrief_mk.tm ckbrief_ck_cov333_id123.bc -t',
  12,
"Summary for: ckbrief_ck_cov333_id123.bc",
"Objects  Interval Begin ET        Interval End ET          AV",
"-------- ------------------------ ------------------------ ---",
"-84100   2007-DEC-04 00:29:10.000 2007-DEC-04 00:30:00.000 Y",
"-84001      -- same --               -- same --            Y",
"-85100   NEED LSK AND SCLK FILES  NEED LSK AND SCLK FILES  Y"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, one id, one segment',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1_id1.bc',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, one id, non-overlaping segments',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov13_id11.bc',
  12,
"Summary for: ckbrief_ck_cov13_id11.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100",
"Begin ET: 2007-DEC-04 00:29:10.000  End ET: 2007-DEC-04 00:30:00.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, one id, overlaping segments, ordered coverages',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov12_id11.bc',
  9,
"Summary for: ckbrief_ck_cov12_id11.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, one id, overlaping segments, out-of-order coverages',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov21_id11.bc',
  9,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, one id, overlaping segments, different frames',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov21_id11_diff_frames.bc',
  9,
"Summary for: ckbrief_ck_cov21_id11_diff_frames.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, one id, overlaping segments, different AV flags',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov21_id11_diff_av.bc',
  9,
"Summary for: ckbrief_ck_cov21_id11_diff_av.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, one id, overlaping segments, -nm',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov21_id11.bc -nm',
  12,
"Summary for: ckbrief_ck_cov21_id11.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100",
"Begin ET: 2007-DEC-04 00:27:55.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, one segment per id, same coverage',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov11_id12.bc',
  10,
"Summary for: ckbrief_ck_cov11_id12.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100",
"         -84001"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, one segment per id, different coverage',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov12_id12.bc',
  12,
"Summary for: ckbrief_ck_cov12_id12.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100",
"Begin ET: 2007-DEC-04 00:27:55.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84001"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, many non-overlaping segments per id',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1313_id1122.bc',
  14,
"Summary for: ckbrief_ck_cov1313_id1122.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100",
"         -84001",
"Begin ET: 2007-DEC-04 00:29:10.000  End ET: 2007-DEC-04 00:30:00.000",
"Objects: -84100",
"         -84001"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, many overlaping segments per id',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1212_id1122.bc',
  10,
"Summary for: ckbrief_ck_cov1212_id1122.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84100",
"         -84001"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, many overlaping segments per id, -nm',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1212_id1122.bc -nm',
  14,
"Summary for: ckbrief_ck_cov1212_id1122.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100",
"         -84001",
"Begin ET: 2007-DEC-04 00:27:55.000  End ET: 2007-DEC-04 00:29:35.000",
"Objects: -84100",
"         -84001"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -n, resolved frame',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -n',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Frames:  PHX_PAYLOAD"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -n, unresolved frame',
  'success',
  $ckbrief,
  '-g ckbrief_lsk.tls ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -n',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Frames:  NO FRAME FOR -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, default time',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1_id1.bc',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin ET: 2007-DEC-04 00:26:40.000  End ET: 2007-DEC-04 00:28:20.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -sclk',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -sclk',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin SCLK: 1/0250000000.000          End SCLK: 1/0250000100.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -dpsclk',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -dpsclk',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin TICKS:   250000000000.           End TICKS:   250000100000.",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -utc',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -utc',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin UTC: 2007-DEC-04 00:25:34.816  End UTC: 2007-DEC-04 00:27:14.816",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -utcdoy',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov1_id1.bc -utcdoy',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin UTC/DOY: 2007-338 // 00:25:34.816  End UTC/DOY: 2007-338 // 00:27:14.816",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, default time, no SCLK',
  'success',
  $ckbrief,
  '-g ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin ET: NEED LSK AND SCLK FILES   End ET: NEED LSK AND SCLK FILES",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -sclk, no SCLK',
  'success',
  $ckbrief,
  '-g ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -sclk',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin SCLK: NEED LSK AND SCLK FILES   End SCLK: NEED LSK AND SCLK FILES",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -dpsclk, no SCLK',
  'success',
  $ckbrief,
  '-g ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -dpsclk',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin TICKS:   250000000000.           End TICKS:   250000100000.",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -utc, no SCLK',
  'success',
  $ckbrief,
  '-g ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -utc',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin UTC: NEED LSK AND SCLK FILES   End UTC: NEED LSK AND SCLK FILES",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -utcdoy, no SCLK',
  'success',
  $ckbrief,
  '-g ckbrief_lsk.tls ckbrief_ck_cov1_id1.bc -utcdoy',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin UTC/DOY: NEED LSK AND SCLK FILES   End UTC/DOY: NEED LSK AND SCLK FILES",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, default time, no LSK',
  'success',
  $ckbrief,
  '-g ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin ET: NEED LSK AND SCLK FILES   End ET: NEED LSK AND SCLK FILES",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -sclk, no LSK',
  'success',
  $ckbrief,
  '-g ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -sclk',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin SCLK: 1/0250000000.000          End SCLK: 1/0250000100.000",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -dpsclk, no LSK',
  'success',
  $ckbrief,
  '-g ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -dpsclk',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin TICKS:   250000000000.           End TICKS:   250000100000.",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -utc, no LSK',
  'success',
  $ckbrief,
  '-g ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -utc',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin UTC: NEED LSK AND SCLK FILES   End UTC: NEED LSK AND SCLK FILES",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, -utcdoy, no LSK',
  'success',
  $ckbrief,
  '-g ckbrief_sclk.tsc ckbrief_ck_cov1_id1.bc -utcdoy',
  9,
"Summary for: ckbrief_ck_cov1_id1.bc",
"Begin UTC/DOY: NEED LSK AND SCLK FILES   End UTC/DOY: NEED LSK AND SCLK FILES",
"Objects: -84100"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, one segment per id, same coverage, no SCLK',
  'success',
  $ckbrief,
  '-g ckbrief_lsk.tls ckbrief_ck_cov11_id12.bc',
  10,
"Summary for: ckbrief_ck_cov11_id12.bc",
"Begin ET: NEED LSK AND SCLK FILES   End ET: NEED LSK AND SCLK FILES",
"Objects: -84100",
"         -84001"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, one segment per id, same coverage, no LSK',
  'success',
  $ckbrief,
  '-g ckbrief_sclk.tsc ckbrief_ck_cov11_id12.bc',
  10,
"Summary for: ckbrief_ck_cov11_id12.bc",
"Begin ET: NEED LSK AND SCLK FILES   End ET: NEED LSK AND SCLK FILES",
"Objects: -84100",
"         -84001"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-g, many ids, one segment per id, same coverage, no SCLK for some',
  'success',
  $ckbrief,
  '-g ckbrief_mk.tm ckbrief_ck_cov333_id123.bc',
  13,
"Summary for: ckbrief_ck_cov333_id123.bc",
"Begin ET: 2007-DEC-04 00:29:10.000  End ET: 2007-DEC-04 00:30:00.000",
"Objects: -84100",
"         -84001",
"Begin ET: NEED LSK AND SCLK FILES   End ET: NEED LSK AND SCLK FILES",
"Objects: -85100"
);

#
# Delete test data
#
print "\n";
print "Deleting test data ...\n";
print "\n";
&test_data( $msopck, $tobin, "delete" );

#
# All done.
#
print "\n";
print "Total: $counttotal --- Passed: $countpass  --- Failed: $countfail\n";
print "\n";

exit;

#
# This routine runs the specified test and prints results to the screen.
#
sub run_test {

  #
  # All argument are inputs. Output is via displaying report message to
  # the screen. Arguments are:
  #
  #    $reporttype  -- lists all types of info to be included into the report
  #                    (possible values are "command", "output", "expvalues")
  #    $maxtocompare - maximum number of characters from each @expvalue line
  #                    to check in inputs; if "", check complete lines
  #    $shortonly   -- flag indicating whether only 'SPICE(...)' line from
  #                    @expvalue should be checked in the output for 
  #                    failure-type cases; "yes" or "no"
  #    $checkcount  -- flag indicating whether the count of output lines
  #                    should be checked; "yes" or "no"
  #    $logname     -- the name of a log file, the contents of which should be
  #                    checked instead of captured STDOUT output; if "",
  #                    STDOUT is checked
  #    $testdesc    -- text line describing test
  #    $testtype    -- "success" or "failure" for expected status 0 or non 0
  #    $progname    -- name of program to run
  #    $commandline -- complete command line
  #    $expcount    -- expected count of output lines
  #    @expvalue    -- an array of strings to look for in the output.
  #                    "?" in these string stands for "any one character".
  #
  ( $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
    $testdesc,
    $testtype,
    $progname,
    $commandline,
    $expcount,
    @expvalue ) = @_;
  $infotypes = $reporttype;
  $report = "";

  $counttotal++;

  #
  # Run the test and save screen output.
  #
  $result = `$progname $commandline 2>&1`;

  #
  # Check exit status vs expected status and reflect then in the report.
  #
  $status = ( $? >> 8 );
  if (    ( ( ! $status ) && $testtype eq "success" ) ||
          ( (   $status ) && $testtype eq "failure" )    ) {
    #
    # Expected status matches returned status. Good.
    #
    $report = "";
  } elsif ( ( ! $status ) && $testtype eq "failure" ) {
    #
    # Expected failure, got success. Bad.
    #
    $report = "\n   ERROR: expected failure but returned with success.\n ";
  } elsif ( (   $status ) && $testtype eq "success" ) {
    #
    # Expected success, got failure. Bad.
    #
    $report = "\n   ERROR: expected success but returned with failure.\n ";
  }

  #
  # Check that output has expected number of lines.
  #
  if ( $checkcount eq "yes" ) {
    $rescount = 0;
    while( $result =~ m/\n/g ) {
      $rescount++;
    }
    if ( $rescount != $expcount ) {
      $report = $report.
      "\n   ERROR: expected $expcount output lines but got $rescount.\n";
    }
  }

  #
  # Check that each of expected lines is present in the output.
  #
  $checkedcount = 0;

  for ($i = 0; $i <= $#expvalue; $i++ ) {

    #
    # Take all or a part of expected value based on $maxtocompare.
    #
    if ( $maxtocompare eq "" ) {
      $shortexpvalue = $expvalue[$i];
    } else {
      $shortexpvalue = substr( $expvalue[$i], 0, $maxtocompare );
    }

    #
    # Pre-process expected value to escape all special regex characters
    # except "?" which, from this routine's point of view, stands for
    # "any one character" and, therefore, get replaced with ".".
    #
    $modexpvalue = $shortexpvalue;
    $modexpvalue =~ s/\\/\\\\/g;
    $modexpvalue =~ s/\n/\\n/g;
    $modexpvalue =~ s/\./\\./g;
    $modexpvalue =~ s/\^/\\^/g;
    $modexpvalue =~ s/\$/\\\$/g;
    $modexpvalue =~ s/\*/\\*/g;
    $modexpvalue =~ s/\+/\\+/g;
    $modexpvalue =~ s/\{/\\{/g;
    $modexpvalue =~ s/\}/\\}/g;
    $modexpvalue =~ s/\[/\\[/g;
    $modexpvalue =~ s/\]/\\]/g;
    $modexpvalue =~ s/\(/\\(/g;
    $modexpvalue =~ s/\)/\\)/g;
    $modexpvalue =~ s/\|/\\|/g;

    $modexpvalue =~ s/\?/\./g;

    #
    # Check if the output contained expected string. First, make an exception
    # for failure-type runs checking only short error messages.
    #
    if ( $testtype  eq "failure" &&
         $shortonly eq "yes"     &&
         ! ( $shortexpvalue =~ /^SPICE\(.+\)$/ ) ) {

      #
      # Don't check this line because it is not a short error message.
      #

    } else {

      if ( $result =~ /$modexpvalue/ ) {

	#
	# Expected string is present in the output. Good.
	#

      } else {

	#
	# Expected string is NOT present in the output. Bad.
	#
	$report = $report.
	 "\n   ERROR: expected string '$shortexpvalue' was not in the output.\n";

      }

      $checkedcount++;

    }

  }

  #
  # Safety belt against poor test setups: verify that we checked at
  # least one line.
  #
  if ( $checkedcount == "0" ) {
    $report = $report.
      "\n   ERROR: bad test case setup: no lines from expected values were checked.\n";
  }

  #
  # Finalize report.
  #
  if ( $report eq "" ) {

    $countpass++;
    $report = "--- passed --- ($testtype) $testdesc\n";

  } else {

    $countfail++;
    $report = "\n".
              "--- FAILED --- ($testtype) $testdesc\n".
              "$report";

    $infotypes = "command output expvalues";

  }

  #
  # Add additonal information to the report as needed.
  #
  if ( $infotypes =~ /command/ ) {
    $report = "$report".
              "\n".
              "   COMMAND --- \n".
              "\n".
              "$progname $commandline\n".
              "\n";
  }

  if ( $infotypes =~ /output/ ) {
    $report = "$report".
              "\n".
              "   OUTPUT --- \n".
              "\n".
              "$result\n".
              "\n";
  }

  if ( $infotypes =~ /expvalues/ ) {
    $report = "$report".
              "\n".
              "   EXPECTED VALUES --- \n".
              "\n";

    for ($i = 0; $i <= $#expvalue; $i++ ) {
      if ( $maxtocompare eq "" ) {
	$report = "$report".
	          "$expvalue[$i]\n";
      } else {
	$report = "$report".
	          substr( $expvalue[$i], 0, $maxtocompare )."\n";
      }
    }
    $report = "$report\n";
  }

  #
  # Display report.
  #
  print $report;

}

#
# This routine generates all necessary kernels.
#
sub test_data {

  #
  # The only inputs are MSOPCK and TOBIN exe locations and action
  # ("make" or "delete"). Outputs are files needed for the test.
  #
  ( $msopck, $tobin, $action ) = @_;
  $myaction = $action;

  #
  # The following files will be made
  #
  #    naif0008.tls --- LSK
  #
  #    ckbrief_sc_1seg.bsp --- SPK with ...
  #
  #
  # LSK and any other text kernels that are needed should be at the
  # top of the list to be made first):
  #
  @files = (
	     "ckbrief_list_one_ck.txt",
	     "ckbrief_list_many_cks.txt",
	     "ckbrief_list_mixed_one_per_line.txt",
	     "ckbrief_list_mixed_many_per_line.txt",
	     "ckbrief_list_mixed_one_line.txt",
	     "ckbrief_list_bad_nonexisting.txt",
	     "ckbrief_list_bad_eof.txt",
	     "ckbrief_list_bad_spk.txt",
	     "ckbrief_list_no_cks.txt",
	     "ckbrief_lsk.tls",
	     "ckbrief_pck.tpc",
	     "ckbrief_fk.tf",
	     "ckbrief_ik.ti",
	     "ckbrief_sclk.tsc",
	     "ckbrief_sclk_id3.tsc",
	     "ckbrief_mk.tm",
	     "ckbrief_mk_no_ck.tm",
	     "ckbrief_mk_one_ck.tm",
	     "ckbrief_mk_many_cks.tm",
	     "ckbrief_pck.bpc",
	     "ckbrief_spk.bsp",
	     "ckbrief_dsk.xds",
	     "ckbrief_dsk.bds",
	     "ckbrief_uk.xu",
	     "ckbrief_uk.bu",
	     "ckbrief_dec.xdc",
	     "ckbrief_te1.xt1",
	     "ckbrief_ek.xes",
	     "ckbrief_ek.bes",
	     "ckbrief_ck_no_seg.bc",
	     "ckbrief_ck_type1.bc",
	     "ckbrief_ck_type2.bc",
	     "ckbrief_ck_type3.bc",
	     "ckbrief_ck_type5.bc",
	     "ckbrief_ck_cov1_id1.xc",
	     "ckbrief_ck_cov1_id1.bc",
	     "ckbrief_ck_cov5_id1.bc",
	     "ckbrief_ck_cov1_id2.bc",
	     "ckbrief_ck_cov1_id3.bc",
	     "ckbrief_ck_cov11_id12.bc",
	     "ckbrief_ck_cov12_id12.bc",
	     "ckbrief_ck_cov13_id12.bc",
	     "ckbrief_ck_cov12_id11.bc",
	     "ckbrief_ck_cov13_id11.bc",
	     "ckbrief_ck_cov21_id11.bc",
	     "ckbrief_ck_cov31_id11.bc",
	     "ckbrief_ck_cov21_id11_diff_av.bc",
	     "ckbrief_ck_cov21_id11_diff_frames.bc",
	     "ckbrief_ck_cov134_id111.bc",
	     "ckbrief_ck_cov1212_id1122.bc",
	     "ckbrief_ck_cov1313_id1122.bc",
	     "ckbrief_ck_cov3311_id2121.bc",
	     "ckbrief_ck_cov13133_id11223.bc",
	     "ckbrief_ck_cov333_id123.bc"
           );

  #
  # Loop through the file list.
  #
  foreach $file ( @files ) {

    #
    # Check if there is anything to be done for this file. Report if
    # there is.
    #
    $myaction = $action;
    if (      (   -e $file && $myaction eq "make"   ) ) {
      print "--- no need to make existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "delete" )   ) {
      print "--- no need to delete non-existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "make"   ) ) {
      print "--- creating $file ...\n";
    } elsif ( (   -e $file && $myaction eq "delete" ) ) {
      print "--- deleting $file ...\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_one_ck.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_one_ck.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ckbrief_ck_cov1_id1.bc
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_many_cks.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_many_cks.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ckbrief_ck_cov21_id11.bc
ckbrief_ck_cov31_id11.bc
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_mixed_one_per_line.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_mixed_one_per_line.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ckbrief_lsk.tls
ckbrief_pck.tpc
ckbrief_fk.tf
ckbrief_sclk.tsc
ckbrief_ck_cov21_id11.bc
ckbrief_ck_cov31_id11.bc
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_mixed_many_per_line.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_mixed_many_per_line.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ckbrief_lsk.tls ckbrief_pck.tpc   ckbrief_fk.tf ckbrief_sclk.tsc
      ckbrief_ck_cov21_id11.bc     ckbrief_ck_cov31_id11.bc
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_mixed_one_line.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_mixed_one_line.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
   ckbrief_lsk.tls    ckbrief_pck.tpc ckbrief_fk.tf ckbrief_sclk.tsc ckbrief_ck_cov21_id11.bc           ckbrief_ck_cov31_id11.bc
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_bad_nonexisting.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_bad_nonexisting.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ckbrief_lsk.tls  ckbrief_pck.tpc ckbrief_fk.tf ckbrief_sclk.tsc
ckbrief_ck.bc
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_bad_eof.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_bad_eof.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT "ckbrief_ck_cov1_id1.bc";
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_bad_spk.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_bad_spk.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ckbrief_lsk.tls  ckbrief_pck.tpc ckbrief_fk.tf ckbrief_sclk.tsc
ckbrief_spk.bsp
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_list_no_cks.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_list_no_cks.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ckbrief_lsk.tls  ckbrief_pck.tpc
ckbrief_fk.tf ckbrief_sclk.tsc
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_lsk.tls" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_lsk.tls" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/LSK

\\begindata

DELTET/DELTA_T_A       =   32.184
DELTET/K               =    1.657D-3
DELTET/EB              =    1.671D-2
DELTET/M               = (  6.239996D0   1.99096871D-7 )

DELTET/DELTA_AT        = ( 10,   \@1972-JAN-1
                           11,   \@1972-JUL-1
                           12,   \@1973-JAN-1
                           13,   \@1974-JAN-1
                           14,   \@1975-JAN-1
                           15,   \@1976-JAN-1
                           16,   \@1977-JAN-1
                           17,   \@1978-JAN-1
                           18,   \@1979-JAN-1
                           19,   \@1980-JAN-1
                           20,   \@1981-JUL-1
                           21,   \@1982-JUL-1
                           22,   \@1983-JUL-1
                           23,   \@1985-JUL-1
                           24,   \@1988-JAN-1
                           25,   \@1990-JAN-1
                           26,   \@1991-JAN-1
                           27,   \@1992-JUL-1
                           28,   \@1993-JUL-1
                           29,   \@1994-JUL-1
                           30,   \@1996-JAN-1
                           31,   \@1997-JUL-1
                           32,   \@1999-JAN-1
                           33,   \@2006-JAN-1 )


\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_pck.tpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_pck.tpc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/PCK

\\begindata

BODY499_POLE_RA          = (  317.68143   -0.1061      0.  )
BODY499_POLE_DEC         = (   52.88650   -0.0609      0.  )
BODY499_PM               = (  176.630    350.89198226  0.  )

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_fk.tf" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_fk.tf" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/FK

\\begindata

FRAME_PHX_TOPO              = -84900
FRAME_-84900_NAME           = 'PHX_TOPO'
FRAME_-84900_CLASS          =  4
FRAME_-84900_CLASS_ID       =  -84900
FRAME_-84900_CENTER         =  -84900
TKFRAME_-84900_RELATIVE     = 'IAU_MARS'
TKFRAME_-84900_SPEC         = 'ANGLES'
TKFRAME_-84900_UNITS        = 'DEGREES'
TKFRAME_-84900_AXES         = (    3,   2,   3 )
TKFRAME_-84900_ANGLES       = ( -234.24871, -21.549327, 180.000 )

FRAME_PHX_LL                =  -84903
FRAME_-84903_NAME           = 'PHX_LL'
FRAME_-84903_CLASS          =  4
FRAME_-84903_CLASS_ID       =  -84903
FRAME_-84903_CENTER         =  -84
TKFRAME_-84903_RELATIVE     = 'PHX_TOPO'
TKFRAME_-84903_SPEC         = 'ANGLES'
TKFRAME_-84903_UNITS        = 'DEGREES'
TKFRAME_-84903_AXES         = (   1,  2,  3 )
TKFRAME_-84903_ANGLES       = ( 180,  0,  0 )

FRAME_PHX_LANDER            = -84001
FRAME_-84001_NAME           = 'PHX_LANDER'
FRAME_-84001_CLASS          =  3
FRAME_-84001_CLASS_ID       = -84001
FRAME_-84001_CENTER         = -84
CK_-84001_SCLK              = -84
CK_-84001_SPK               = -84

FRAME_PHX_PAYLOAD           = -84100
FRAME_-84100_NAME           = 'PHX_PAYLOAD'
FRAME_-84100_CLASS          =  3
FRAME_-84100_CLASS_ID       = -84100
FRAME_-84100_CENTER         = -84
CK_-84100_SCLK              = -84
CK_-84100_SPK               = -84

FRAME_PHX_TOPO_R            =  -84905
FRAME_-84905_NAME           = 'PHX_TOPO_R'
FRAME_-84905_CLASS          =  5
FRAME_-84905_CLASS_ID       =  -84905
FRAME_-84905_CENTER         =  -84900
FRAME_-84905_RELATIVE       = 'J2000'
FRAME_-84905_DEF_STYLE      = 'PARAMETERIZED'
FRAME_-84905_FAMILY         = 'TWO-VECTOR'
FRAME_-84905_PRI_AXIS       = 'Z'
FRAME_-84905_PRI_VECTOR_DEF = 'OBSERVER_TARGET_POSITION'
FRAME_-84905_PRI_OBSERVER   = 'MARS'
FRAME_-84905_PRI_TARGET     = '-84900'
FRAME_-84905_PRI_ABCORR     = 'NONE'
FRAME_-84905_SEC_AXIS       = 'X'
FRAME_-84905_SEC_VECTOR_DEF = 'CONSTANT'
FRAME_-84905_SEC_FRAME      = 'IAU_MARS'
FRAME_-84905_SEC_SPEC       = 'RECTANGULAR'
FRAME_-84905_SEC_VECTOR     =  ( 0, 0, 1 )

FRAME_PCK3001               = 3001
FRAME_3001_NAME             = 'PCK3001'
FRAME_3001_CLASS            = 2
FRAME_3001_CLASS_ID         = 3001
FRAME_3001_CENTER           = 399

FRAME_FIXED3002             =  3002
FRAME_3002_NAME             = 'FIXED3002'
FRAME_3002_CLASS            =  4
FRAME_3002_CLASS_ID         =  3002
FRAME_3002_CENTER           =  399
TKFRAME_3002_RELATIVE       = 'ITRF93'
TKFRAME_3002_SPEC           = 'ANGLES'
TKFRAME_3002_UNITS          = 'DEGREES'
TKFRAME_3002_AXES           = (   1,  2,  3 )
TKFRAME_3002_ANGLES         = (   0,  0,  0 )

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ik.ti" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ik.ti" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/IK

\\begindata

FRAME_PHX_TOPO              = -84900
FRAME_-84900_NAME           = 'PHX_TOPO'
FRAME_-84900_CLASS          =  4
FRAME_-84900_CLASS_ID       =  -84900
FRAME_-84900_CENTER         =  -84900
TKFRAME_-84900_RELATIVE     = 'IAU_MARS'
TKFRAME_-84900_SPEC         = 'ANGLES'
TKFRAME_-84900_UNITS        = 'DEGREES'
TKFRAME_-84900_AXES         = (    3,   2,   3 )
TKFRAME_-84900_ANGLES       = ( -234.24871, -21.549327, 180.000 )

FRAME_PHX_LL                =  -84903
FRAME_-84903_NAME           = 'PHX_LL'
FRAME_-84903_CLASS          =  4
FRAME_-84903_CLASS_ID       =  -84903
FRAME_-84903_CENTER         =  -84
TKFRAME_-84903_RELATIVE     = 'PHX_TOPO'
TKFRAME_-84903_SPEC         = 'ANGLES'
TKFRAME_-84903_UNITS        = 'DEGREES'
TKFRAME_-84903_AXES         = (   1,  2,  3 )
TKFRAME_-84903_ANGLES       = ( 180,  0,  0 )

FRAME_PHX_LANDER            = -84001
FRAME_-84001_NAME           = 'PHX_LANDER'
FRAME_-84001_CLASS          =  3
FRAME_-84001_CLASS_ID       = -84001
FRAME_-84001_CENTER         = -84
CK_-84001_SCLK              = -84
CK_-84001_SPK               = -84

FRAME_PHX_PAYLOAD           = -84100
FRAME_-84100_NAME           = 'PHX_PAYLOAD'
FRAME_-84100_CLASS          =  3
FRAME_-84100_CLASS_ID       = -84100
FRAME_-84100_CENTER         = -84
CK_-84100_SCLK              = -84
CK_-84100_SPK               = -84

FRAME_PHX_TOPO_R            =  -84905
FRAME_-84905_NAME           = 'PHX_TOPO_R'
FRAME_-84905_CLASS          =  5
FRAME_-84905_CLASS_ID       =  -84905
FRAME_-84905_CENTER         =  -84900
FRAME_-84905_RELATIVE       = 'J2000'
FRAME_-84905_DEF_STYLE      = 'PARAMETERIZED'
FRAME_-84905_FAMILY         = 'TWO-VECTOR'
FRAME_-84905_PRI_AXIS       = 'Z'
FRAME_-84905_PRI_VECTOR_DEF = 'OBSERVER_TARGET_POSITION'
FRAME_-84905_PRI_OBSERVER   = 'MARS'
FRAME_-84905_PRI_TARGET     = '-84900'
FRAME_-84905_PRI_ABCORR     = 'NONE'
FRAME_-84905_SEC_AXIS       = 'X'
FRAME_-84905_SEC_VECTOR_DEF = 'CONSTANT'
FRAME_-84905_SEC_FRAME      = 'IAU_MARS'
FRAME_-84905_SEC_SPEC       = 'RECTANGULAR'
FRAME_-84905_SEC_VECTOR     =  ( 0, 0, 1 )

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_sclk.tsc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_sclk.tsc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/SCLK

   \\begindata

      SCLK_KERNEL_ID                = (  \@20-JUL-2008     )

      SCLK_DATA_TYPE_84             = (                 1 )

      SCLK01_TIME_SYSTEM_84         = (                 1 )
      SCLK01_N_FIELDS_84            = (                 2 )
      SCLK01_MODULI_84              = ( 10000000000  1000 )
      SCLK01_OFFSETS_84             = (           0     0 )
      SCLK01_OUTPUT_DELIM_84        = (                 1 )

      SCLK_PARTITION_START_84       = ( 0.0000000000000E+00 )
      SCLK_PARTITION_END_84         = ( 1.00000000E+14      )
      SCLK01_COEFFICIENTS_84        = ( 0.00000000E+00
                                        \@01-JAN-2000-12:00:00
                                        1  )

   \\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_sclk_id3.tsc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_sclk_id3.tsc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/SCLK

   \\begindata

      SCLK_KERNEL_ID                = (  \@20-JUL-2008     )

      SCLK_DATA_TYPE_85             = (                 1 )

      SCLK01_TIME_SYSTEM_85         = (                 1 )
      SCLK01_N_FIELDS_85            = (                 2 )
      SCLK01_MODULI_85              = ( 10000000000  1000 )
      SCLK01_OFFSETS_85             = (           0     0 )
      SCLK01_OUTPUT_DELIM_85        = (                 1 )

      SCLK_PARTITION_START_85       = ( 0.0000000000000E+00 )
      SCLK_PARTITION_END_85         = ( 1.00000000E+14      )
      SCLK01_COEFFICIENTS_85        = ( 0.00000000E+00
                                        \@01-JAN-2000-12:00:10
                                        1  )

   \\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_mk.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_mk.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/MK

\\begindata

KERNELS_TO_LOAD = (
'ckbrief_lsk.tls',
'ckbrief_pck.tpc',
'ckbrief_fk.tf',
'ckbrief_sclk.tsc'
)

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_mk_no_ck.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_mk_no_ck.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/MK

\\begindata

KERNELS_TO_LOAD = (
'ckbrief_lsk.tls',
'ckbrief_pck.tpc',
'ckbrief_fk.tf'
'ckbrief_sclk.tsc'
'ckbrief_spk.bsp'
)

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_mk_one_ck.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_mk_one_ck.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/MK

\\begindata

KERNELS_TO_LOAD = (
'ckbrief_lsk.tls',
'ckbrief_pck.tpc',
'ckbrief_fk.tf'
'ckbrief_sclk.tsc'
'ckbrief_ck_cov1_id1.bc'
)

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_mk_many_cks.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_mk_many_cks.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/MK

\\begindata

KERNELS_TO_LOAD = (
'ckbrief_lsk.tls',
'ckbrief_pck.tpc',
'ckbrief_fk.tf'
'ckbrief_sclk.tsc'
'ckbrief_ck_cov1_id2.bc'
'ckbrief_ck_cov1_id3.bc'
)

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_pck.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_pck.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov1_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'BB9'
'11'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_spk.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_spk.bsp" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bsp$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'NAIF/DAF'
'2'
'6'
'LandmarksSPK                                                '
BEGIN_ARRAY 1 16
'LS                                      '
'1E1DC4^7'
'BC186AC^8'
'-14BA4'
'1F3'
'271E'
'8'
16
'-2DC012D87331D2^3'
'-3F8C52F60D6E98^3'
'C3F49570653768^3'
'0^0'
'0^0'
'0^0'
'-2DC012D87331D2^3'
'-3F8C52F60D6E98^3'
'C3F49570653768^3'
'0^0'
'0^0'
'0^0'
'1E1DC4^7'
'BA368E8^8'
'1^1'
'2^1'
END_ARRAY 1 16
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~

This file contains landing site location defined by with the following
Gaussian coordinates:

Lon =  234.248710 degrees East
Lat =  68.450673 degrees North
Alt =  -2.591214 km

These Gaussian coordinates correspond to the following areocentric
coordinates (R, LON, LAT) = (3376.340, 234.248710, 68.218394) and Mars radii
(Re, Re, Rp) = (3396.19, 3396.19, 3376.20).

The corresponding XYZ coordinates were computed by PINPOINT for the
triaxial ellipsoid surface defined by the body 499 radii from
PcK file 'mars_iau2000_v0.tpc'.

 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_dsk.xds" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_dsk.xds" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DASETF NAIF DAS ENCODED TRANSFER FILE
'DAS/DSK '
'DSK type 3 test kernel                                      '
'0'
'0'
'0'
'0'
'0'
'D3'
'E'
BEGIN_DP_BLOCK 1 211
'270F^4'
'1^1'
'0^0'
'1^1'
'3^1'
'-3243F6A8885A3^1'
'3243F6A8885A3^1'
'-1921FB54442D18^1'
'1921FB54442D18^1'
'F4391FE8EF202^0'
'11D8C7E110394F^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFB^1'
'FFD06592B414B8^0'
'FB2A532519DC8^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B8^1'
'FA63764A8AA74^0'
'F4391FE8EF2038^0'
'F43920ECABE3F^0'
'FA637976DEB9E^0'
'10787C79B02F8C^1'
'11D8C7C5EB1E6C^1'
'11D8C7DDE25211^1'
'10787CB66C1561^1'
'FA637F14EB541^0'
'F43928389DA22^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C68^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCB^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D3^0'
'FA637D8BBCCEA8^0'
'10787CA5D11521^1'
'11D8C7D754E01B^1'
'11D8C7DC7D51AA^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C88^0'
'F43927CBEBFBA8^0'
'FA637EC13D92^0'
'10787CB2E35DAD^1'
'11D8C7DC7D51A9^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB48^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4E^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8D^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AA^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8C^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AB^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB58^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4D^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7DC7D51A9^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA8^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C7^0'
'F43927CBEBFBA^0'
'FA637EC13D92^0'
'10787CB2E35DAE^1'
'11D8C7DC7D51AA^1'
'11D8C7DDE25212^1'
'10787CB66C156^1'
'FA637F14EB541^0'
'F43928389DA21^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C78^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCA^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D2^0'
'FA637D8BBCCEA8^0'
'10787CA5D1152^1'
'11D8C7D754E01B^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFA^1'
'FFD06592B414B8^0'
'FB2A532519DC7^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B7^1'
'FA63764A8AA75^0'
'F4391FE8EF2038^0'
'F43920ECABE3E^0'
'FA637976DEB9F^0'
'10787C79B02F8D^1'
'11D8C7C5EB1E6C^1'
END_DP_BLOCK 1 211
TOTAL_DP_BLOCKS 1 211
BEGIN_INTEGER_BLOCK 1 14
'F4240'
'4'
'4'
'-1'
'-1'
'B'
'3'
'0'
'D3'
'0'
'0'
'14'
'A'
'1'
END_INTEGER_BLOCK 1 14
TOTAL_INTEGER_BLOCKS 1 14
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #

    if ( $file eq "ckbrief_dsk.bds" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_dsk.bds" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bds$/.xds/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_uk.xu" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_uk.xu" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/UK  '
'2'
'6'
'test                                                        '
BEGIN_ARRAY 1 6
'test                                    '
'0^0'
'0^0'
'-3E8'
'1'
'1'
'0'
6
'1^1'
'0^0'
'0^0'
'0^0'
'0^0'
'1^1'
END_ARRAY 1 6
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
   In the SPICE system, pointing data for science instruments are stored in
   the C-kernel, the ``C'' in SPICE. The pointing of an instrument is often
   expressed in terms of a transformation matrix from some standard base
   reference frame to a local, instrument-fixed frame. In the past, the
   instrument was often a camera, and the transformation was thus dubbed
   the ``C-matrix''; hence the choice of C as the name for the pointing
   kernel.

   The data contained in C-kernel files can be accessed and manipulated by
   a collection of FORTRAN 77 subroutines which are part of the SPICELIB
   library. These subroutines can be integrated into user application
   programs. The purpose of this document is to describe both the C-kernel
   file structure and the associated SPICELIB software to the level of
   detail necessary for the user to program almost any application.

   With few exceptions, all subroutines and functions appearing in this
   document are part of SPICELIB. The exceptions are placeholders for
   user-supplied routines which appear in some of the code examples. Each
   SPICELIB routine is prefaced with a complete SPICELIB header which
   describes inputs, outputs, restrictions and context, and provides
   examples of usage. The authoritative documentation for any subroutine is
   its header, which should be consulted before using the routine in any
   program. A summary of the CK subroutines presented in this document is
   included as Appendix A.

 ~NAIF/SPC END COMMENTS~
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_uk.bu" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_uk.bu" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bu$/.xu/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_dec.xdc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_dec.xdc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
'NAIF/DAF'                       
test
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_te1.xt1" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_te1.xt1" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
TE1/EK        
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #

    if ( $file eq "ckbrief_ek.xes" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ek.xes" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT <<EndBlock;
DASETF NAIF DAS ENCODED TRANSFER FILE
'DAS/EK  '
'DSK type 3 test kernel                                      '
'0'
'0'
'0'
'0'
'0'
'D3'
'E'
BEGIN_DP_BLOCK 1 211
'270F^4'
'1^1'
'0^0'
'1^1'
'3^1'
'-3243F6A8885A3^1'
'3243F6A8885A3^1'
'-1921FB54442D18^1'
'1921FB54442D18^1'
'F4391FE8EF202^0'
'11D8C7E110394F^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFB^1'
'FFD06592B414B8^0'
'FB2A532519DC8^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B8^1'
'FA63764A8AA74^0'
'F4391FE8EF2038^0'
'F43920ECABE3F^0'
'FA637976DEB9E^0'
'10787C79B02F8C^1'
'11D8C7C5EB1E6C^1'
'11D8C7DDE25211^1'
'10787CB66C1561^1'
'FA637F14EB541^0'
'F43928389DA22^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C68^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCB^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D3^0'
'FA637D8BBCCEA8^0'
'10787CA5D11521^1'
'11D8C7D754E01B^1'
'11D8C7DC7D51AA^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C88^0'
'F43927CBEBFBA8^0'
'FA637EC13D92^0'
'10787CB2E35DAD^1'
'11D8C7DC7D51A9^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB48^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4E^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8D^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AA^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8C^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AB^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB58^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4D^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7DC7D51A9^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA8^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C7^0'
'F43927CBEBFBA^0'
'FA637EC13D92^0'
'10787CB2E35DAE^1'
'11D8C7DC7D51AA^1'
'11D8C7DDE25212^1'
'10787CB66C156^1'
'FA637F14EB541^0'
'F43928389DA21^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C78^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCA^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D2^0'
'FA637D8BBCCEA8^0'
'10787CA5D1152^1'
'11D8C7D754E01B^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFA^1'
'FFD06592B414B8^0'
'FB2A532519DC7^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B7^1'
'FA63764A8AA75^0'
'F4391FE8EF2038^0'
'F43920ECABE3E^0'
'FA637976DEB9F^0'
'10787C79B02F8D^1'
'11D8C7C5EB1E6C^1'
END_DP_BLOCK 1 211
TOTAL_DP_BLOCKS 1 211
BEGIN_INTEGER_BLOCK 1 14
'F4240'
'4'
'4'
'-1'
'-1'
'B'
'3'
'0'
'D3'
'0'
'0'
'14'
'A'
'1'
END_INTEGER_BLOCK 1 14
TOTAL_INTEGER_BLOCKS 1 14
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #

    if ( $file eq "ckbrief_ek.bes" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ek.bes" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bes$/.xes/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_no_seg.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_no_seg.bc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/CK  '
'2'
'6'
'test                                                        '
TOTAL_ARRAYS 0
 ~NAIF/SPC BEGIN COMMENTS~

This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.

 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_type1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_type1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 1
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000001.000 0 0 0 0 0 0
250000101.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_type2.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_type2.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 2
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 2
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 250000001.000 0 0 0 0 0 0
250000100.000 250000101.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 250000001.000 0 0 0 0 0 0
250000100.000 250000101.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_type3.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_type3.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 3
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000002.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
250000102.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000002.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
250000102.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_type5.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_type5.bc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/CK  '
'2'
'6'
'ATNM_MGS_SEARCH.BC                                          '
BEGIN_ARRAY 1 181
'ATNM_MGS_SEARCH.MEX                     '
'69F7C87538D998^B'
'69F7D0F538D984^B'
'-A029'
'1'
'5'
'1'
181
'13A376^0'
'-B2F33A^0'
'-7FF43B^0'
'8170E^0'
'121A41C^0'
'-B20728^0'
'-7F95FC^0'
'834962^0'
'1098CC4^0'
'-B1222A^0'
'-7F2ECF^0'
'85131^0'
'F27CEA^-1'
'-B040C8^0'
'-7EC02D^0'
'86D0F8^0'
'DC1904^-1'
'-AF6EB^0'
'-7E4863^0'
'88773E^0'
'C6D52A^-1'
'-AEA092^0'
'-7DC8B6^0'
'8A13BA^0'
'B1F22^-1'
'-ADDD5A^0'
'-7D4601^0'
'8B9B3E^0'
'9E35B2^-1'
'-AD1E7C^0'
'-7CBB47^0'
'8D1A5C^0'
'8ACD16^-1'
'-AC6872^0'
'-7C2F5E^0'
'8E873C^0'
'784FF3^-1'
'-ABB4D4^0'
'-7BA021^0'
'8FEBA6^0'
'6660B^-1'
'-AB0B1C^0'
'-7B0D9D^0'
'913F9E^0'
'551059^-1'
'-AA61BC^0'
'-7A7BED^0'
'928B86^0'
'446342^-1'
'-A9C15A^0'
'-79E6BD^0'
'93C96C^0'
'344F21^-1'
'-A92314^0'
'-795249^0'
'94FE5C^0'
'24B9B98^-1'
'-A889D6^0'
'-78BE86^0'
'96278A^0'
'15CBC58^-1'
'-A7F5A4^0'
'-782945^0'
'974728^0'
'748331^-2'
'-A7631E^0'
'-779615^0'
'985E94^0'
'-6B195^-2'
'-A6D6DE^0'
'-770234^0'
'996B4A^0'
'-141884^-1'
'-A64C0C^0'
'-766F47^0'
'9A71A8^0'
'-213E158^-1'
'-A5C69E^0'
'-75DE96^0'
'9B6CB8^0'
'-2DA1EC8^-1'
'-A542A4^0'
'-754D1E^0'
'9C636A^0'
'-39E47B^-1'
'-A4C3F^0'
'-74BE82^0'
'9D4F12^0'
'-4580F5^-1'
'-A44516^0'
'-7430C6^0'
'9E374C^0'
'-50D92C^-1'
'-A3CD9E^0'
'-73A3EB^0'
'9F145C^0'
'-5BBC43^-1'
'-A353C^0'
'-731A76^0'
'9FEEDE^0'
'-664EB3^-1'
'-A2E192^0'
'-7290D6^0'
'A0BF2E^0'
'-707141^-1'
'-A26D9^0'
'-7209E1^0'
'A18D3E^0'
'-7A6215^-1'
'-A1FF28^0'
'-7184AF^0'
'A25238^0'
'-83CC9^-1'
'-A190E^0'
'-710047^0'
'A314B^0'
'-8D1A0A^-1'
'-A1260C^0'
'-707EF2^0'
'A3CF9A^0'
'-95F438^-1'
'-A0BCA^0'
'-6FFE37^0'
'A4871E^0'
'-9E92D6^-1'
'-A055D^0'
'-6F7F5D^0'
'A53922^0'
'-A6F5EE^-1'
'-9FF008^0'
'-6F0337^0'
'A5E6C2^0'
'-AF1CB^-1'
'-9F8B74^0'
'-6E87BB^0'
'A6914E^0'
'-B75DC6^-1'
'-9F272A^0'
'-6E0F3C^0'
'A737D4^0'
'69F7C87538D998^B'
'69F7C8B538D95C^B'
'69F7C8F538D9A4^B'
'69F7C93538D968^B'
'69F7C97538D988^B'
'69F7C9B538D97C^B'
'69F7C9F538D994^B'
'69F7CA3538D9B^B'
'69F7CA7538D978^B'
'69F7CAB538D994^B'
'69F7CAF538D994^B'
'69F7CB3538D9A8^B'
'69F7CB7538D978^B'
'69F7CBB538D9BC^B'
'69F7CBF538D984^B'
'69F7CC3538D9A^B'
'69F7CC7538D99^B'
'69F7CCB538D9AC^B'
'69F7CCF538D974^B'
'69F7CD3538D99^B'
'69F7CD7538D98^B'
'69F7CDB538D99C^B'
'69F7CDF538D95C^B'
'69F7CE3538D978^B'
'69F7CE7538D99^B'
'69F7CEB538D984^B'
'69F7CEF538D9A4^B'
'69F7CF3538D99^B'
'69F7CF7538D9B^B'
'69F7CFB538D974^B'
'69F7CFF538D994^B'
'69F7D03538D98^B'
'69F7D07538D9A^B'
'69F7D0B538D964^B'
'69F7D0F538D984^B'
'69F7C87538D998^B'
'1^-3'
'1^1'
'A^1'
'1^1'
'23^2'
END_ARRAY 1 181
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov1_id1.xc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov1_id1.xc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/CK  '
'2'
'6'
'CK FOR CKBRIEF TESTING                                      '
BEGIN_ARRAY 1 19
'CK FOR CKBRIEF TESTING                  '
'3A352944^A'
'3A352ACAA^A'
'-14884'
'-14BA7'
'3'
'1'
19
'1^1'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'1^1'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'3A352944^A'
'3A352ACAA^A'
'3A352944^A'
'1^1'
'2^1'
END_ARRAY 1 19
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov1_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov1_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov5_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov5_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov1_id2.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov1_id2.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov1_id3.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov1_id3.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk_id3.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -85100
REFERENCE_FRAME_NAME  = 'J2000'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov11_id12.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov11_id12.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov12_id12.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov12_id12.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov13_id12.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov13_id12.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov12_id11.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov12_id11.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov13_id11.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov13_id11.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov21_id11.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov21_id11.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov31_id11.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov31_id11.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov21_id11_diff_av.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov21_id11_diff_av.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'NO'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0
250000175.000 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0
250000175.000 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov21_id11_diff_frames.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov21_id11_diff_frames.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'IAU_MARS'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov134_id111.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov134_id111.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000125.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000125.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov1212_id1122.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov1212_id1122.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov1313_id1122.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov1313_id1122.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov3311_id2121.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov3311_id2121.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov13133_id11223.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov13133_id11223.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk_id3.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -85100
REFERENCE_FRAME_NAME  = 'J2000'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "ckbrief_ck_cov333_id123.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "ckbrief_ck_cov333_id123.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'ckbrief_lsk.tls'
SCLK_FILE_NAME        = 'ckbrief_sclk_id3.tsc'
FRAMES_FILE_NAME      = 'ckbrief_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR CKBRIEF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR CKBRIEF TESTING'
INSTRUMENT_ID         = -85100
REFERENCE_FRAME_NAME  = 'J2000'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 1
PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

  }

}
