#!/usr/bin/perl
# /bin/perl
# /usr/contrib/bin/perl
# /cygdrive/c/Perl/bin/perl
#
# This script tests MSOPCK. It includes two rouines: test_data and
# run_test. test_data is called once to generate all needed files;
# run_test is called once for each test case and reports to the screen.
#
$version = "1.0.0 -- August 28, 2006 -- BVS/NAIF";

#---------------------------------------------------------------------------
# Begin of configuration parameter section. See descriptions below.
#---------------------------------------------------------------------------

#
# For UNIX
#
$msopck        = "./msopck";
$maxtocompare  = "";
$shortonly     = "no";
$checkcount    = "yes";
$qt            = "'";

#
# For Windows
#
$msopck        = ".\\msopck";
$maxtocompare  = "77";
$shortonly     = "yes";
$checkcount    = "no";
$qt            = "";

#
# For CYGWIN
#
#$msopck        = "msopck";
#$maxtocompare  = "";
#$shortonly     = "no";
#$checkcount    = "yes";
#$qt            = "'";

#
# Configurable parameters:
#
# $msopck               Executables invoked by and other files used by
#                       the script.
#
# $reporttype           Information types that test cases should report
#                       (space delimited list including any combination
#                       of these words "command output expvalues")
#
# $maxtocompare         The number of characters of each expected value
#                       to be used in comparison. To use all characters
#                       it must be set to "".
#
# $shortonly            Flag indicating whether for failure-type cases
#                       only short error message should be checked
#                       ("yes" or "no").
#
# $checkcount           Flag indicating whether the output line count
#                       should be checked ("yes" or "no").
#
# $logname              Log file name and log file option.
# $logopt
#
# $qt                   Quote used to quote command line keys and
#                       values that cannot be specified unquoted (for
#                       example [] must be passed as '[]' to Unix
#                       shells)
#
#
# $deleteck             Flag indicating whether good test CKs should
#                       be deleted: "yes" or "no".
#
#
# $doslowtests          Flag indicating whether slow (large file) tests
#                       should be done: "yes" or "no".
#
#
# $postruncleanup       Flag indicating whether setup, inputs, etc. should
#                       be deleted after the run: "yes" or "no".
#

$reporttype = " ";

$logname = "";
$logopt  = "";
#$logname = "tmp.log";
#$logopt  = "-l tmp.log ";

$deleteck = 'yes';
#$deleteck = 'no';

$doslowtests = "yes";
#$doslowtests = "no";

$postruncleanup = "yes";
#$postruncleanup = "no";


#---------------------------------------------------------------------------
# End of configuration parameter section.
#---------------------------------------------------------------------------

#
# These counters are global variables incremented by run_test routine. (Yuck!)
#
$counttotal = 0;
$countpass  = 0;
$countfail  = 0;

#
# Generate test report banner. Include OS name and date.
#
$seconds = time;
($sec,$min,$hours,$mday,$mon,$year,$wday,$yday) = gmtime($seconds);

print  "\n";
print  "MSOPCK Test Suite, Version -- $version\n";
print  "\n";
printf "--- DATE: %4d-%02d-%02d %02d:%02d:%02d GMT\n",
       $year+1900, $mon+1, $mday, $hours, $min, $sec;
print  "--- OS:   $^O\n";

#
# Run MSOPCK with put command line arguments and dump its output to
# the screen to remove any ambiguity of what version is tested.
#

$result = `$msopck 2>&1`;
print "\n";
print "Testing the following MSOPCK:\n";
print "\n";
print "--- $msopck\n";
print "\n";
print "$result";

#
# Prepare test data
#
print "\n";
print "Preparing test data ...\n";
print "\n";
&test_data( "make" );

#
# Run tests.
#
print "\n";
print "Executing tests ...\n";
print "\n";

#
# Start with "success" type tests.
#

#
# Benchmark CK dumps.
#
@basicck1withav = (
'  BTIME              0.000',
'  ETIME         450000.000',
'T(1)              0.000',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(1) +0.00872665  0.00000000  0.00000000',
'T(2)         180000.000',
'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
'R(2) +0.03490659  0.00000000  0.00000000',
'T(3)         225000.000',
'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
'R(3) +0.03490659  0.00000000  0.00000000',
'T(4)         270000.000',
'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
'R(4) +0.00872665  0.00000000  0.00000000',
'T(5)         450000.000',
'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(5) +0.00872665  0.00000000  0.00000000'
);

@basicck1noav = (
'  BTIME              0.000',
'  ETIME         450000.000',
'T(1)              0.000',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'T(2)         180000.000',
'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
'T(3)         225000.000',
'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
'T(4)         270000.000',
'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
'T(5)         450000.000',
'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000'
);

@basicck2inputav = (
'  BTIME              0.000',
'  ETIME         455000.000',
'B(1)              0.000',
'E(1)         175000.000',
'S(1)              0.001',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(1) +0.00872665  0.00000000  0.00000000',
'B(2)         180000.000',
'E(2)         220000.000',
'S(2)              0.001',
'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
'R(2) +0.03490659  0.00000000  0.00000000',
'B(3)         225000.000',
'E(3)         265000.000',
'S(3)              0.001',
'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
'R(3) +0.03490659  0.00000000  0.00000000',
'B(4)         270000.000',
'E(4)         445000.000',
'S(4)              0.001',
'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
'R(4) +0.00872665  0.00000000  0.00000000',
'B(5)         450000.000',
'E(5)         455000.000',
'S(5)              0.001',
'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(5) +0.00872665  0.00000000  0.00000000'
);

@basicck2madeupav = (
'  BTIME              0.000',
'  ETIME         450000.010',
'B(1)              0.000',
'E(1)         180000.000',
'S(1)              0.001',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(1) +0.00872665  0.00000000  0.00000000',
'B(2)         180000.000',
'E(2)         225000.000',
'S(2)              0.001',
'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
'R(2) +0.03490659  0.00000000  0.00000000',
'B(3)         225000.000',
'E(3)         270000.000',
'S(3)              0.001',
'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
'R(3) +0.03490659  0.00000000  0.00000000',
'B(4)         270000.000',
'E(4)         450000.000',
'S(4)              0.001',
'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
'R(4) +0.00872665  0.00000000  0.00000000',
'B(5)         450000.000',
'E(5)         450000.010',
'S(5)              0.001',
'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(5)  0.00000000  0.00000000  0.00000000'
);

@basicck3withav = (
'  BTIME              0.000',
'  ETIME         450000.000',
'T(1)              0.000',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(1) +0.00872665  0.00000000  0.00000000',
'T(2)         180000.000',
'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
'R(2) +0.03490659  0.00000000  0.00000000',
'T(3)         225000.000',
'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
'R(3) +0.03490659  0.00000000  0.00000000',
'T(4)         270000.000',
'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
'R(4) +0.00872665  0.00000000  0.00000000',
'T(5)         450000.000',
'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(5) +0.00872665  0.00000000  0.00000000',
'I(1)              0.000'
);

@basicck3withavrgav = (
'  BTIME              0.000',
'  ETIME         450000.000',
'T(1)              0.000',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(1) +0.00872665  0.00000000  0.00000000',
'T(2)         180000.000',
'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
'R(2) +0.02181662  0.00000000  0.00000000',
'T(3)         225000.000',
'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
'R(3) +0.03490659  0.00000000  0.00000000',
'T(4)         270000.000',
'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
'R(4) +0.02181662  0.00000000  0.00000000',
'T(5)         450000.000',
'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(5) +0.00872665  0.00000000  0.00000000',
'I(1)              0.000'
);

@basicck3noav = (
'  BTIME              0.000',
'  ETIME         450000.000',
'T(1)              0.000',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'T(2)         180000.000',
'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
'T(3)         225000.000',
'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
'T(4)         270000.000',
'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
'T(5)         450000.000',
'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
'I(1)              0.000'
);

@betterck3withav = (
'  BTIME        2000000.000',
'  ETIME        2180000.000',
'T(1)        2000000.000',
'Q(1) +0.88162808 +0.03266701 -0.26925564 -0.38622040',
'R(1) -0.00121448 +0.00290490 -0.00373554',
'T(2)        2060000.000',
'Q(2) +0.89073651 +0.00071949 -0.36059455 -0.27669393',
'R(2) -0.00082567 +0.00297839 -0.00393031',
'T(3)        2120000.000',
'Q(3) +0.88112033 -0.04429624 -0.44274875 -0.16011978',
'R(3) -0.00047262 +0.00299458 -0.00409380',
'T(4)        2180000.000',
'Q(4) +0.85144431 -0.09982852 -0.51328094 -0.04024333',
'R(4) -0.00047262 +0.00299458 -0.00409380',
'I(1)        2000000.000'
);

@betterck3withoffset = (
'  BTIME        2000000.000',
'  ETIME        2180000.000',
'T(1)        2000000.000',
'Q(1) +0.12293964 +0.49041157 -0.01489414 -0.86264738',
'R(1) +0.00044387 -0.00206470 -0.00440541',
'T(2)        2060000.000',
'Q(2) +0.24264957 +0.53480317 -0.06028296 -0.80713860',
'R(2) +0.00029947 -0.00174711 -0.00467523',
'T(3)        2120000.000',
'Q(3) +0.36064219 +0.56034902 -0.11444025 -0.73678329',
'R(3) +0.00019727 -0.00143466 -0.00488395',
'T(4)        2180000.000',
'Q(4) +0.47218117 +0.56657751 -0.17508366 -0.65221207',
'R(4) +0.00019727 -0.00143466 -0.00488395',
'I(1)        2000000.000'
);


#
# Test possible time for format for one time tag.
#
$outputck = "ck_test1.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process input tagged with SCLK',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test2.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process input tagged with SCLK with partition',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av_sclkstr.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test3.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process input tagged with DP SCLK',
  'success',
  $msopck,
  "setup_good_3_dsclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test4.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process input tagged with ET',
  'success',
  $msopck,
  "setup_good_3_et_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test5.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process input tagged with SCLK ticks',
  'success',
  $msopck,
  "setup_good_3_ticks_ang_av_all.txt input_good_ang_av_ticks.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test6.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process input tagged with UTC',
  'success',
  $msopck,
  "setup_good_3_utc_ang_av_all.txt input_good_ang_av_utc.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };


#
# Test possible times for format for two time tags.
#
$outputck = "ck_test7.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process CK2 input with two SCLKs',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_av_all.txt input_good_ang_av_twotimes.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2inputav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test8.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process CK2 input with two SCLKs with partitions',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_av_all.txt input_good_ang_av_sclkstr_twotimes.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2inputav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test9.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process CK2 input with two DP SCLKs',
  'success',
  $msopck,
  "setup_good_2_dsclk_ang_av_all.txt input_good_ang_av_twotimes.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2inputav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test10.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process CK2 input with two ETs',
  'success',
  $msopck,
  "setup_good_2_et_ang_av_all.txt input_good_ang_av_twotimes.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2inputav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test11.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process CK2 input with two SCLK ticks',
  'success',
  $msopck,
  "setup_good_2_ticks_ang_av_all.txt input_good_ang_av_ticks_twotimes.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2inputav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test12.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process CK2 input with two UTCs',
  'success',
  $msopck,
  "setup_good_2_utc_ang_av_all.txt input_good_ang_av_utc_twotimes.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2inputav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };


#
# test making CKs with/without angular rates.
#
$outputck = "ck_test13.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK1 with angular rates',
  'success',
  $msopck,
  "setup_good_1_sclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  91,
  '   CKID -999000', '  REFID 1', '   TYPE 1', ' AVFLAG 1',
  @basicck1withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test14.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK1 without angular rates (rates present in the input)',
  'success',
  $msopck,
  "setup_good_1_sclk_ang_noav_all.txt input_good_ang_av.txt $outputck",
  86,
  '   CKID -999000', '  REFID 1', '   TYPE 1', ' AVFLAG 0',
  @basicck1noav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test15.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK1 without angular rates (rates not present in the input)',
  'success',
  $msopck,
  "setup_good_1_sclk_ang_noav_all.txt input_good_ang_only.txt $outputck",
  86,
  '   CKID -999000', '  REFID 1', '   TYPE 1', ' AVFLAG 0',
  @basicck1noav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };


$outputck = "ck_test16.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK3 with angular rates',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test17.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK3 without angular rates (rates present in the input)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_noav_all.txt input_good_ang_av.txt $outputck",
  87,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 0',
  @basicck3noav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test18.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK3 without angular rates (rates not present in the input)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_noav_all.txt input_good_ang_only.txt $outputck",
  87,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 0',
  @basicck3noav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };


#
# Test processing all types of inputs
#
$outputck = "ck_test19.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process angles in degrees on the input',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test20.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process angles in radians on the input',
  'success',
  $msopck,
  "setup_good_3_sclk_angrad_av_all.txt input_good_ang_radians_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test21.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process SPICE quaternions on the input',
  'success',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_good_squat_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test22.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process MSOP quaternions on the input',
  'success',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_good_mquat_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test23.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: process matrixes on the input',
  'success',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_good_mat_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };


#
# Test making up angular rates.
#
$outputck = "ck_test24.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK3 with made-up/averaged AVs (rates present on the input)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_maav_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withavrgav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test25.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK3 with made-up/not-averaged AVs (rates present on the input)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_mana_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test26.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK2 with made-up/averaged AVs (rates present on the input)',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_maav_all.txt input_good_ang_av.txt $outputck",
  101,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2madeupav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test27.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK2 with made-up/not-averaged AVs (rates present on the input)',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_mana_all.txt input_good_ang_av.txt $outputck",
  101,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2madeupav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };


$outputck = "ck_test28.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK3 with made-up/averaged AVs (rates not present on the input) ',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_maav_all.txt input_good_ang_only.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withavrgav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test29.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK3 with made-up/not-averaged AVs (rates not present on the input)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_mana_all.txt input_good_ang_only.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test30.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK2 with made-up/averaged AVs (rates not present on the input)',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_maav_all.txt input_good_ang_only.txt $outputck",
  101,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2madeupav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test31.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make CK2 with made-up/not-averaged AVs (rates not present on the input)',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_mana_all.txt input_good_ang_only.txt $outputck",
  101,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2madeupav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Tests with more sophisticated input rotations.
#
$outputck = "ck_test32.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, angles in SPACE order',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_better_ang_space.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test33.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, matrixes',
  'success',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_good_better_mat.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test34.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, SPICE quaternions',
  'success',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_good_better_squat.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test35.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, MSOP quaternions',
  'success',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_good_better_mquat.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test36.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, angles in SPACE order',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_body.txt input_good_better_ang_body.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test37.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, angles in radians',
  'success',
  $msopck,
  "setup_good_3_sclk_angrad_av_all.txt input_good_better_ang_rad.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test38.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, rates in INSTRUMENT frame',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_inst.txt input_good_better_rate_inst.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test39.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, offset in degrees',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_offsetdeg.txt input_good_better_ang_space.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withoffset
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test40.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, offset in radians',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_offsetrad.txt input_good_better_ang_space.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withoffset
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test41.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, offset axes as 123',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_offset123.txt input_good_better_ang_space.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withoffset
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test42.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, rotation axes given as 123',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_axes123.txt input_good_better_ang_space.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test43.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: better input, MAKE UP/NO AVERAGING rates',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_mana_all.txt input_good_better_ang_space.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @betterck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Check for correct interpolation intervals for types 2 and 3 using basic input.
#
$outputck = "ck_test44.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: tight tolerance for type 3 resulting in all singleton intervals',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_tol1.txt input_good_ang_av.txt $outputck",
  100,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:01:55.816',
  '      2000-01-01T12:02:40.816    2000-01-01T12:02:40.816',
  '      2000-01-01T12:03:25.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test45.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: medium tolerance for type 3 resulting in a few gaps',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_tol50.txt input_good_ang_av.txt $outputck",
  96,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test46.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: tight tolerance for type 2 resulting in all singleton intervals ',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_mana_tol1.txt input_good_ang_only.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:01:55.816',
  '      2000-01-01T12:02:40.816    2000-01-01T12:02:40.816',
  '      2000-01-01T12:03:25.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test47.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: medium tolerance for type 2 resulting in few gaps',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_mana_tol50.txt input_good_ang_only.txt $outputck",
  103,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Basic downsampling check (the two middle points were dropped.)
#
$outputck = "ck_test48.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: basic down sampling',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_dsmpl.txt input_good_ang_av_dsmpl.txt $outputck",
  89,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         450000.000',
  'T(1)              0.000',
  'T(2)         180000.000',
  'T(3)         247500.000',
  'T(4)         450000.000',
  'I(1)              0.000'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test for SCLK ID picked from FK.
#
$outputck = "ck_test49.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: pick SCLK ID from FK',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_sclk888.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test for appending to an existing CK.
#
$outputck = "ck_test50.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: append to an exiting CK (step 1 -- make CK)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: append to an exiting CK (step 2 -- append to CK)',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_av_all.txt input_good_ang_av_twotimes.txt $outputck",
  120,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  @basicck2inputav,
  'SEGMENT 1',
  'SEGMENT 2'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test time correction.
#
$outputck = "ck_test51.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: apply time bias (2.013 sec)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_timecor.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME           2013.000',
  '  ETIME         452013.000',
  'T(1)           2013.000',
  'T(2)         182013.000',
  'T(3)         227013.000',
  'T(4)         272013.000',
  'T(5)         452013.000',
  'I(1)           2013.000'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test comments (clean and with non-printing chars).
#
$outputck = "ck_test52.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: check clean comments',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav,
  'Test comments.1',
  'Test comments.2',
  'Test comments.3',
  'Test comments.4',
  'Test comments.5',
  'Test comments.6',
  'Test comments.7'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test53.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: check comments with non-printing characters',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_tabcmt.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav,
  'Test comments.a1',
  ' Test comments.a2',
  '  Test comments.a3',
  '   Test comments.a4',
  '    Test comments.a5',
  '     Test comments.a6',
  '      Test comments.a7'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test54.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: check empty comments',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_empcmt.txt input_good_ang_av.txt $outputck",
  85,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test setup and table on the screen output.
#
$outputck = "ck_test55.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: check for setup and interpolation table on the output',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av.txt $outputck",
  92,
  "********************************************************************************",
  "Test comments.1",
  "Test comments.2",
  "Test comments.3",
  "Test comments.4",
  "Test comments.5",
  "Test comments.6",
  "Test comments.7",
  "MSOPCK SETUP FILE: setup_good_3_sclk_ang_av_all.txt",
  "KPL/SCLK",
  "\\begindata",
  "      LSK_FILE_NAME           = 'lsk_good.tls'",
  "      SCLK_FILE_NAME          = 'sclk_good_999.tsc'",
  "      FRAMES_FILE_NAME        = 'fk_good.tf'",
  "      INTERNAL_FILE_NAME      = 'test'",
  "      COMMENTS_FILE_NAME      = 'comments_good.txt'",
  "      CK_TYPE                 = 3",
  "      CK_SEGMENT_ID           = 'test'",
  "      INSTRUMENT_ID           = -999000",
  "      REFERENCE_FRAME_NAME    = 'J2000'",
  "      ANGULAR_RATE_PRESENT    = 'YES'",
  "      QUATERNION_NORM_ERROR   = 0.0001",
  "      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )",
  "      MAXIMUM_VALID_INTERVAL  = 450.0",
  "      TIME_CORRECTION         = 0.0",
  "      INPUT_TIME_TYPE         = 'SCLK'",
  "      INPUT_DATA_TYPE         = 'EULER ANGLES'",
  "      EULER_ANGLE_UNITS       = 'DEGREES'",
  "      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )",
  "      EULER_ROTATIONS_TYPE    = 'SPACE'",
  "      ANGULAR_RATE_FRAME      = 'REFERENCE'",
  "      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )",
  "      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )",
  "      OFFSET_ROTATION_UNITS   = 'DEGREES'",
  "      DOWN_SAMPLE_TOLERANCE   = 0.0",
  "      INCLUDE_INTERVAL_TABLE  = 'YES'",
  "      PRODUCER_ID             = 'BVS/NAIF'",
  "      DUMP_OUTPUT_CK          = 'YES'",
  "\\begintext",
  "RUN-TIME OBTAINED META INFORMATION:",
  "PRODUCT_CREATION_TIME = ",
  "START_TIME            = 2000-01-01T11:58:55.816",
  "STOP_TIME             = 2000-01-01T12:06:25.816",
  "INTERPOLATION INTERVALS IN THE FILE SEGMENTS:",
  "SEG.SUMMARY: ID -999000, COVERG: 2000-01-01T11:58:55.816 2000-01-01T12:06:25.816",
  "--------------------------------------------------------------------------------",
  "      2000-01-01T11:58:55.816    2000-01-01T12:06:25.816"
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test quaternion and angular rate filters.
#
$outputck = "ck_test56.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: check rate filtering (1)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_rfilter1.txt input_good_ang_av.txt $outputck",
  93,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
'  BTIME              0.000',
'  ETIME         450000.000',
'T(1)              0.000',
'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(1) +0.00872665  0.00000000  0.00000000',
'T(2)         270000.000',
'Q(2) +0.70710678 +0.70710678  0.00000000  0.00000000',
'R(2) +0.00872665  0.00000000  0.00000000',
'T(3)         450000.000',
'Q(3) +1.00000000  0.00000000  0.00000000  0.00000000',
'R(3) +0.00872665  0.00000000  0.00000000',
'I(1)              0.000',
'BAD DATA RECORDS FROM THE INPUT FILE: 2 OF 5 (40.00%)',
'BAD RATE ON LINE 2: 180.0  90. 0 0 2.0 0 0',
'BAD RATE ON LINE 3: 225.0 180. 0 0 2.0 0 0'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test57.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: check rate filtering (2)',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_rfilter2.txt input_good_better_ang_space.txt $outputck",
  88,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME        2000000.000',
  '  ETIME        2000000.000',
  'T(1)        2000000.000',
  'Q(1) +0.88162808 +0.03266701 -0.26925564 -0.38622040',
  'R(1) -0.00121448 +0.00290490 -0.00373554',
  'BAD DATA RECORDS FROM THE INPUT FILE: 3 OF 4 (75.00%)',
  'BAD RATE ON LINE 2: 2060.000     15.000000     40.000000     40.000000   -0.04730743    0.17064915   -0.22519019',
  'BAD RATE ON LINE 3: 2120.000     20.000000     50.000000     30.000000   -0.02707935    0.17157707   -0.23455726',
  'BAD RATE ON LINE 4: 2180.000     25.000000     60.000000     20.000000   -0.02707935    0.17157707   -0.23455726',
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test58.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: check quaternion filtering',
  'success',
  $msopck,
  "setup_good_3_sclk_squat_av_qfilter.txt input_good_squat_av_qfilter.txt $outputck",
  91,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         270000.000',
  'T(1)              0.000',
  'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(1) +0.00872665  0.00000000  0.00000000',
  'T(2)         270000.000',
  'Q(2) +0.70710678 +0.70710678  0.00000000  0.00000000',
  'R(2) +0.00872665  0.00000000  0.00000000',
  'I(1)              0.000',
  'BAD DATA RECORDS FROM THE INPUT FILE: 3 OF 5 (60.00%)',
  'BAD QAUT ON LINE 2: 180.0  0.70710678 -0.70710678  0.00000000  0.10000000 0.03490658503989 0 0',
  'BAD QAUT ON LINE 3: 225.0  0.00000000 -1.00000000  0.10000000  0.00000000 0.03490658503989 0 0',
  'BAD QAUT ON LINE 5: 450.0  0.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Check making fake SCLKs.
#
$outputck = "ck_test59.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make fake SCLK with derived ID',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_fsclk999.txt input_good_ang_av.txt $outputck",
  91,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };
if ( $deleteck eq "yes" ) { unlink( "sclk_fake_999.tsc" ) };

$outputck = "ck_test60.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: make fake SCLK with ID picked from FK',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_av_fsclk888.txt input_good_ang_av.txt $outputck",
  92,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };
if ( $deleteck eq "yes" ) { unlink( "sclk_fake_888.tsc" ) };

#
# Check help, usage and template displays
#
@outputusage = (
"MSOPCK Utility Program, ",
"Usage:",
"  > msopck <setup_file> <input_file> <output_ck_file>"
);

@outputhelp = (
"MSOPCK Utility Program, ",
"   This program creates type 1, 2 or 3 CK file from an input",
"   orientation data provided in a text file as quaternions,",
"   euler angles or matrices tagged by UTC, SCLK, or ET times.",
"   See MSOPCK User's Guide for more information."
);

@outputtemplate = (
"MSOPCK Utility Program, ",
"   MSOPCK Setup File Template. See MSOPCK User's Guide for more",
"   information.",
"   \\begindata",
"      LSK_FILE_NAME           = 'LSK file name'",
"      SCLK_FILE_NAME          = 'SCLK file name'",
"         or",
"      MAKE_FAKE_SCLK          = 'fake SCLK file name'",
"      FRAMES_FILE_NAME        = 'FK file name'",
"      INTERNAL_FILE_NAME      = 'internal file name string'",
"      COMMENTS_FILE_NAME      = 'file containing comments'",
"      CK_TYPE                 = 1, 2, or 3",
"      CK_SEGMENT_ID           = 'segment ID string'",
"      INSTRUMENT_ID           = NAIF instrument ID",
"      REFERENCE_FRAME_NAME    = 'reference frame name'",
"      ANGULAR_RATE_PRESENT    = 'YES', 'NO', 'MAKE UP', or",
"                                'MAKE UP/NO AVERAGING'",
"      QUATERNION_NORM_ERROR   = maximum normalization error",
"      ANGULAR_RATE_THRESHOLD  = ( max X rate, rad/sec",
"                                  max Y rate, rad/sec",
"                                  max Z rate, rad/sec )",
"      MAXIMUM_VALID_INTERVAL  = interval length, seconds",
"      TIME_CORRECTION         = bias to be appiled to input times, seconds",
"      INPUT_TIME_TYPE         = 'SCLK', 'UTC', 'TICKS', 'DSCLK', or 'ET'",
"      INPUT_DATA_TYPE         = 'MSOP QUATERNIONS',",
"                                'SPICE QUATERNIONS',",
"                                'EULER ANGLES', or",
"                                'MATRICES'",
"      EULER_ANGLE_UNITS       = 'DEGREES' or 'RADIANS'",
"      EULER_ROTATIONS_ORDER   = rotation axes; example: ( 'X' 'Y' 'Z' )",
"      EULER_ROTATIONS_TYPE    = 'BODY' or 'SPACE' (default SPACE)",
"      ANGULAR_RATE_FRAME      = 'REFERENCE' or 'INSTRUMENT'",
"      OFFSET_ROTATION_ANGLES  = angles; example: ( 0.5, 0.1, 0.1 )",
"      OFFSET_ROTATION_AXES    = rotation axes: example: ( 'X' 'Y' 'Z' )",
"      OFFSET_ROTATION_UNITS   = 'DEGREES' or 'RADIANS'",
"      DOWN_SAMPLE_TOLERANCE   = down sampling tolerance, radians",
"      INCLUDE_INTERVAL_TABLE  = 'YES' or 'NO' (default 'YES')",
"      PRODUCER_ID             = 'producer group/person name'",
"   \\begintext"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: usage display for blank command line',
  'success',
  $msopck,
  " ",
  7,
  @outputusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: usage display for one unrecognized argument',
  'success',
  $msopck,
  " boo1",
  7,
  @outputusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: usage display for two unrecognized arguments',
  'success',
  $msopck,
  " boo1 boo2",
  7,
  @outputusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: usage display for more than 3 unrecognized arguments',
  'success',
  $msopck,
  " boo1 boo2 boo3 boo4",
  7,
  @outputusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: help display for -h',
  'success',
  $msopck,
  " -h",
  9,
  @outputhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: help display for -H',
  'success',
  $msopck,
  " -H",
  9,
  @outputhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: help display for -HeLp',
  'success',
  $msopck,
  " -HeLp",
  9,
  @outputhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: help display for -h with extra arguments',
  'success',
  $msopck,
  " -h boo",
  9,
  @outputhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: template display for -t',
  'success',
  $msopck,
  " -t",
  51,
  @outputtemplate
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: template display for -T',
  'success',
  $msopck,
  " -T",
  51,
  @outputtemplate
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: template display for -TeMpLaTe',
  'success',
  $msopck,
  " -TeMpLaTe",
  51,
  @outputtemplate
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: template display for -t with extra arguments',
  'success',
  $msopck,
  " -t boo",
  51,
  @outputtemplate
);

#
# Check for made up AVs with various interpolation intervals for types 2 and 3 using basic input.
#
$outputck = "ck_test61.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: MADE UP AVs for type 3 with all singleton intervals',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_maav_tol1.txt input_good_ang_av.txt $outputck",
  100,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         450000.000',
  'T(1)              0.000',
  'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(1)  0.00000000  0.00000000  0.00000000',
  'T(2)         180000.000',
  'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
  'R(2)  0.00000000  0.00000000  0.00000000',
  'T(3)         225000.000',
  'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
  'R(3)  0.00000000  0.00000000  0.00000000',
  'T(4)         270000.000',
  'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
  'R(4)  0.00000000  0.00000000  0.00000000',
  'T(5)         450000.000',
  'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(5)  0.00000000  0.00000000  0.00000000',
  'I(1)              0.000',
  'I(2)         180000.000',
  'I(3)         225000.000',
  'I(4)         270000.000',
  'I(5)         450000.000',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:01:55.816',
  '      2000-01-01T12:02:40.816    2000-01-01T12:02:40.816',
  '      2000-01-01T12:03:25.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test62.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: MADE UP AVs for type 3 with a few gaps',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_maav_tol50.txt input_good_ang_av.txt $outputck",
  96,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         450000.000',
  'T(1)              0.000',
  'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(1)  0.00000000  0.00000000  0.00000000',
  'T(2)         180000.000',
  'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
  'R(2) +0.03490659  0.00000000  0.00000000',
  'T(3)         225000.000',
  'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
  'R(3) +0.03490659  0.00000000  0.00000000',
  'T(4)         270000.000',
  'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
  'R(4) +0.03490659  0.00000000  0.00000000',
  'T(5)         450000.000',
  'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(5)  0.00000000  0.00000000  0.00000000',
  'I(1)              0.000',
  'I(2)         180000.000',
  'I(3)         450000.000',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test63.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: MADE UP/NO AVERAGING AVs for type 3 with all singleton intervals',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_mana_tol1.txt input_good_ang_av.txt $outputck",
  100,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         450000.000',
  'T(1)              0.000',
  'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(1)  0.00000000  0.00000000  0.00000000',
  'T(2)         180000.000',
  'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
  'R(2)  0.00000000  0.00000000  0.00000000',
  'T(3)         225000.000',
  'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
  'R(3)  0.00000000  0.00000000  0.00000000',
  'T(4)         270000.000',
  'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
  'R(4)  0.00000000  0.00000000  0.00000000',
  'T(5)         450000.000',
  'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(5)  0.00000000  0.00000000  0.00000000',
  'I(1)              0.000',
  'I(2)         180000.000',
  'I(3)         225000.000',
  'I(4)         270000.000',
  'I(5)         450000.000',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:01:55.816',
  '      2000-01-01T12:02:40.816    2000-01-01T12:02:40.816',
  '      2000-01-01T12:03:25.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test64.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: MADE UP/NO AVERAGING AVs for type 3 with a few gaps',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_mana_tol50.txt input_good_ang_av.txt $outputck",
  96,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         450000.000',
  'T(1)              0.000',
  'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(1)  0.00000000  0.00000000  0.00000000',
  'T(2)         180000.000',
  'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
  'R(2) +0.03490659  0.00000000  0.00000000',
  'T(3)         225000.000',
  'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
  'R(3) +0.03490659  0.00000000  0.00000000',
  'T(4)         270000.000',
  'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
  'R(4) +0.03490659  0.00000000  0.00000000',
  'T(5)         450000.000',
  'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(5)  0.00000000  0.00000000  0.00000000',
  'I(1)              0.000',
  'I(2)         180000.000',
  'I(3)         450000.000',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test65.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: MADE UP AVs type 2 with all singleton intervals ',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_mana_tol1.txt input_good_ang_only.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         450000.010',
  'B(1)              0.000',
  'E(1)              0.010',
  'S(1)              0.001',
  'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(1)  0.00000000  0.00000000  0.00000000',
  'B(2)         180000.000',
  'E(2)         180000.010',
  'S(2)              0.001',
  'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
  'R(2)  0.00000000  0.00000000  0.00000000',
  'B(3)         225000.000',
  'E(3)         225000.010',
  'S(3)              0.001',
  'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
  'R(3)  0.00000000  0.00000000  0.00000000',
  'B(4)         270000.000',
  'E(4)         270000.010',
  'S(4)              0.001',
  'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
  'R(4)  0.00000000  0.00000000  0.00000000',
  'B(5)         450000.000',
  'E(5)         450000.010',
  'S(5)              0.001',
  'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(5)  0.00000000  0.00000000  0.00000000',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:01:55.816',
  '      2000-01-01T12:02:40.816    2000-01-01T12:02:40.816',
  '      2000-01-01T12:03:25.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test66.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: MADE UP AVs type 2 with a few gaps',
  'success',
  $msopck,
  "setup_good_2_sclk_ang_mana_tol50.txt input_good_ang_only.txt $outputck",
  103,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  '  BTIME              0.000',
  '  ETIME         450000.010',
  'B(1)              0.000',
  'E(1)              0.010',
  'S(1)              0.001',
  'Q(1) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(1)  0.00000000  0.00000000  0.00000000',
  'B(2)         180000.000',
  'E(2)         225000.000',
  'S(2)              0.001',
  'Q(2) +0.70710678 -0.70710678  0.00000000  0.00000000',
  'R(2) +0.03490659  0.00000000  0.00000000',
  'B(3)         225000.000',
  'E(3)         270000.000',
  'S(3)              0.001',
  'Q(3)  0.00000000 -1.00000000  0.00000000  0.00000000',
  'R(3) +0.03490659  0.00000000  0.00000000',
  'B(4)         270000.000',
  'E(4)         270000.010',
  'S(4)              0.001',
  'Q(4) +0.70710678 +0.70710678  0.00000000  0.00000000',
  'R(4)  0.00000000  0.00000000  0.00000000',
  'B(5)         450000.000',
  'E(5)         450000.010',
  'S(5)              0.001',
  'Q(5) +1.00000000  0.00000000  0.00000000  0.00000000',
  'R(5)  0.00000000  0.00000000  0.00000000',
  '      2000-01-01T11:58:55.816    2000-01-01T11:58:55.816',
  '      2000-01-01T12:01:55.816    2000-01-01T12:03:25.816',
  '      2000-01-01T12:06:25.816    2000-01-01T12:06:25.816'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test setup contaning only required keywords.
#
$outputck = "ck_test67.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: setup file for CK 1 containing only required keywords',
  'success',
  $msopck,
  "setup_good_1_sclk_ang_av_req.txt input_good_ang_av.txt $outputck",
  66,
  '   CKID -999000', '  REFID 1', '   TYPE 1', ' AVFLAG 1',
  @basicck1withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test68.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: setup file for CK 3 containing only required keywords',
  'success',
  $msopck,
  "setup_good_3_sclk_mat_av_req.txt input_good_mat_av.txt $outputck",
  65,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 1',
  @basicck3withav
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# Test multi segment output for large inputs.
#
if ( $doslowtests eq "yes" ) {

$outputck = "ck_test69.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: large input (NBUFF-1), one segment output',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_noav_all.txt input_good_large_nbuff_m1.txt $outputck",
  200075,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 0',
  'SEGMENT 1',
  '  BTIME           1000.000',
  '  ETIME       99999000.000'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test70.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: large input (NBUFF), one segment output',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_noav_all.txt input_good_large_nbuff.txt $outputck",
  200077,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 0',
  'SEGMENT 1',
  '  BTIME           1000.000',
  '  ETIME      100000000.000'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test71.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: large input (NBUFF+1), two segment output',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_noav_all.txt input_good_large_nbuff_p1.txt $outputck",
  200095,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 0',
  'SEGMENT 1',
  '  BTIME           1000.000',
  '  ETIME      100000000.000',
  'SEGMENT 2',
  '  BTIME      100000000.000',
  '  ETIME      100001000.000'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

$outputck = "ck_test72.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: large input (2*NBUFF), three segment output',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_noav_all.txt input_good_large_2nbuff.txt $outputck",
  400109,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 0',
  'SEGMENT 1',
  '  BTIME           1000.000',
  '  ETIME      100000000.000',
  'SEGMENT 2',
  '  BTIME      100000000.000',
  '  ETIME      199999000.000',
  'SEGMENT 3',
  '  BTIME      199999000.000',
  '  ETIME      200000000.000'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

}

#
# Test for one point input.
#
$outputck = "ck_test73.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: one point input',
  'success',
  $msopck,
  "setup_good_3_sclk_ang_noav_all.txt input_good_one_point.txt $outputck",
  79,
  '   CKID -999000', '  REFID 1', '   TYPE 3', ' AVFLAG 0',
  'SEGMENT 1',
  '  BTIME         777000.000',
  '  ETIME         777000.000'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };


#
# For averaging of SCLK rates in CK 2.
#
$outputck = "ck_test74.bc";
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'good: averaged SCLK rates in CK 2',
  'success',
  $msopck,
  "setup_good_2_avg_sclk_rates.txt input_good_ang_av_twotimes.txt $outputck",
  105,
  '   CKID -999000', '  REFID 1', '   TYPE 2', ' AVFLAG 1',
  'S(1)              0.003',
  'S(2)              0.003',
  'S(3)              0.003',
  'S(4)              0.003',
  'S(5)              0.003'
);
if ( $deleteck eq "yes" ) { unlink( "$outputck" ) };

#
# "success" tests not done:
#
# -- exlclude interval table (needs to be but cannot be tested with
#    current "must be present on output" approach)
#
# -- long/chopped internal file name, segment ID and producer ID
#    (needs to be but cannot be tested without running extra tools
#    and hitting 80 char termila limit)
#
# -- all details about what exatly gets put into comments
#    (needs to be but cannot be tested without running extra tools
#    and hitting 80 char termila limit)
#

#
# End of "success" tests; beginnig of "failure" tests.
#
print "\n";

#
# Tests in this block deal with bad input files
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: empty input file',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_empty.txt ck_failure.bc",
  16,
  'SPICE(EMPTYINPUTFILE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: input file with all blank lines',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_blank_line_all.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: input with leading blank line',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_blank_line_leading.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: input with trailing blank line',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_blank_line_trailing.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: input with blank line in the middle',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_blank_line_middle.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: tab delimited input',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_delimited_tab.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: comma delimited input',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_delimited_comma.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad start time, SCLK',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_time_numeric.txt ck_failure.bc",
  16,
  'SPICE(INVALIDSCLKSTRING)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad start time, DSCLK',
  'failure',
  $msopck,
  "setup_good_3_dsclk_ang_av_all.txt input_bad_time_numeric.txt ck_failure.bc",
  16,
  'SPICE(BADDECIMALSCLK1)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad start time, ET',
  'failure',
  $msopck,
  "setup_good_3_et_ang_av_all.txt input_bad_time_numeric.txt ck_failure.bc",
  17,
  'SPICE(BADET1)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad start time, TICKS',
  'failure',
  $msopck,
  "setup_good_3_ticks_ang_av_all.txt input_bad_time_numeric.txt ck_failure.bc",
  17,
  'SPICE(BADDPSCLK1)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad start time, UTC',
  'failure',
  $msopck,
  "setup_good_3_utc_ang_av_all.txt input_bad_time_utc.txt ck_failure.bc",
  17,
  'SPICE(UNPARSEDTIME)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad stop time, SCLK',
  'failure',
  $msopck,
  "setup_good_2_sclk_ang_av_all.txt input_bad_time_numeric_stop.txt ck_failure.bc",
  16,
  'SPICE(INVALIDSCLKSTRING)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad stop time, DSCLK',
  'failure',
  $msopck,
  "setup_good_2_dsclk_ang_av_all.txt input_bad_time_numeric_stop.txt ck_failure.bc",
  16,
  'SPICE(BADDECIMALSCLK2)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad stop time, ET',
  'failure',
  $msopck,
  "setup_good_2_et_ang_av_all.txt input_bad_time_numeric_stop.txt ck_failure.bc",
  17,
  'SPICE(BADET2)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad stop time, TICKS',
  'failure',
  $msopck,
  "setup_good_2_ticks_ang_av_all.txt input_bad_time_numeric_stop.txt ck_failure.bc",
  17,
  'SPICE(BADDPSCLK2)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad stop time (UTC)',
  'failure',
  $msopck,
  "setup_good_2_utc_ang_av_all.txt input_bad_time_utc_stop.txt ck_failure.bc",
  17,
  'SPICE(UNPARSEDTIME)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad angle, element 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_angle_numeric_1.txt ck_failure.bc",
  16,
  'SPICE(BADANGLE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad angle, element 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_angle_numeric_2.txt ck_failure.bc",
  16,
  'SPICE(BADANGLE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad angle, element 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_angle_numeric_3.txt ck_failure.bc",
  16,
  'SPICE(BADANGLE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few angles, only 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_angle_too_few_1.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few angles, only 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_angle_too_few_2.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad rate, element 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_rate_numeric_1.txt ck_failure.bc",
  17,
  'SPICE(BADANGULARRATE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad rate, element 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_rate_numeric_2.txt ck_failure.bc",
  17,
  'SPICE(BADANGULARRATE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad rate, element 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_rate_numeric_3.txt ck_failure.bc",
  17,
  'SPICE(BADANGULARRATE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few rate elements, only 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_rate_too_few_1.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few rate elements, only 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_bad_rate_too_few_2.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad SPICE quat, element 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_squat_numeric_1.txt ck_failure.bc",
  17,
  'SPICE(BADSPICEQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad SPICE quat, element 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_squat_numeric_2.txt ck_failure.bc",
  17,
  'SPICE(BADSPICEQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad SPICE quat, element 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_squat_numeric_3.txt ck_failure.bc",
  17,
  'SPICE(BADSPICEQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad SPICE quat, element 4',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_squat_numeric_4.txt ck_failure.bc",
  17,
  'SPICE(BADSPICEQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few SPICE quat elements, only 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_squat_too_few_1.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few SPICE quat elements, only 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_squat_too_few_2.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few SPICE quat elements, only 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_squat_too_few_3.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad MSOP quat, element 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_bad_mquat_numeric_1.txt ck_failure.bc",
  17,
  'SPICE(BADMSOPQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad MSOP quat, element 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_bad_mquat_numeric_2.txt ck_failure.bc",
  17,
  'SPICE(BADMSOPQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad MSOP quat, element 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_bad_mquat_numeric_3.txt ck_failure.bc",
  17,
  'SPICE(BADMSOPQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad MSOP quat, element 4',
  'failure',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_bad_mquat_numeric_4.txt ck_failure.bc",
  17,
  'SPICE(BADMSOPQUATERNION)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few MSOP quat elements, only 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_bad_mquat_too_few_1.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few MSOP quat elements, only 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_bad_mquat_too_few_2.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few MSOP quat elements, only 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_mquat_av_all.txt input_bad_mquat_too_few_3.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_1.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_2.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_3.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 4',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_4.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 5',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_5.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 6',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_6.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 7',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_7.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 8',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_8.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: bad matrix, element 9',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_numeric_9.txt ck_failure.bc",
  16,
  'SPICE(BADMATRIX)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 1',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_1.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 2',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_2.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 3',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_3.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 4',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_4.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 5',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_5.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 6',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_6.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 7',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_7.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: too few matrix elements, only 8',
  'failure',
  $msopck,
  "setup_good_3_sclk_mat_av_all.txt input_bad_mat_too_few_8.txt ck_failure.bc",
  17,
  'SPICE(BADINPUTDATALINE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: duplicate times with MAKE UP CK3',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_maav_all.txt input_bad_duplicate_times.txt ck_failure.bc",
  17,
  'SPICE(IDENTICALTIMES2)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: duplicate times with MAKE UP/NO AVERAGING for CK3',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_mana_all.txt input_bad_duplicate_times.txt ck_failure.bc",
  17,
  'SPICE(IDENTICALTIMES2)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: duplicate times with MAKE UP CK2',
  'failure',
  $msopck,
  "setup_good_2_sclk_ang_maav_all.txt input_bad_duplicate_times.txt ck_failure.bc",
  17,
  'SPICE(IDENTICALTIMES1)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: duplicate times with MAKE UP/NO AVERAGING for CK2',
  'failure',
  $msopck,
  "setup_good_2_sclk_ang_mana_all.txt input_bad_duplicate_times.txt ck_failure.bc",
  17,
  'SPICE(IDENTICALTIMES1)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: all quaternion are non-unit and filtered out',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_quats_nonunit_all.txt ck_failure.bc",
  17,
  'SPICE(NOACCEPTABLEDATA)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad inputs: all avs are too large and filtered out',
  'failure',
  $msopck,
  "setup_good_3_sclk_squat_av_all.txt input_bad_too_large_avs.txt ck_failure.bc",
  17,
  'SPICE(NOACCEPTABLEDATA)'
);

#
# All tests in this block deal with bad command line arguments
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad command line: setup file does not exist',
  'failure',
  $msopck,
  "nonexistent_setup input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(SETUPDOESNOTEXIST)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad command line: input file does not exist',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt nonexistent_input ck_failure.bc",
  17,
  'SPICE(INPUTDOESNOTEXIST)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad command line: existing output file is not a CK',
  'failure',
  $msopck,
  "setup_good_3_sclk_ang_av_all.txt input_good_ang_av.txt lsk_bad_empty.tls",
  17,
  'SPICE(NOTACKFILE)'
);

#
# All tests in this block deal with bad supporting kernels
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: using empty LSK',
  'failure',
  $msopck,
  "setup_bad_empty_lsk.txt input_good_ang_av.txt ck_failure.bc",
  25,
  'SPICE(MISSINGTIMEINFO)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: using empty SCLK',
  'failure',
  $msopck,
  "setup_bad_empty_sclk.txt input_good_ang_av.txt ck_failure.bc",
  16,
  'SPICE(KERNELVARNOTFOUND)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: using empty FK',
  'failure',
  $msopck,
  "setup_bad_empty_fk.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(UNRECOGNIZEDFRAME)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: not type 1 SCLK with DSCLK times',
  'failure',
  $msopck,
  "setup_bad_sclk_not_type_1.txt input_good_ang_av.txt ck_failure.bc",
  19,
  'SPICE(NOTTYPE1SCLK)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: not two field SCLK with DSCLK times',
  'failure',
  $msopck,
  "setup_bad_sclk_one_field.txt input_good_ang_av.txt ck_failure.bc",
  19,
  'SPICE(NOTTWOFIELDSCLK)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: not two moduli SCLK with DSCLK times',
  'failure',
  $msopck,
  "setup_bad_sclk_one_moduli.txt input_good_ang_av.txt ck_failure.bc",
  19,
  'SPICE(NOTTWOMODULI)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: not two offsets SCLK with DSCLK times',
  'failure',
  $msopck,
  "setup_bad_sclk_one_offset.txt input_good_ang_av.txt ck_failure.bc",
  20,
  'SPICE(NOTTWOOFFSETS)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: SCLK without COEFF; error for CK2',
  'failure',
  $msopck,
  "setup_bad_sclk_no_coeffs.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(SCLKCOEFFSNOTFOUND)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: SCLK without MODULI; error for CK2',
  'failure',
  $msopck,
  "setup_bad_sclk_no_moduli.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(SCLKMODULINOTFOUND)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad kernels: SCLK with zero moduli; error for CK2',
  'failure',
  $msopck,
  "setup_bad_sclk_zero_moduli.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADSCLKDATA)'
);

#
# All tests in this block deal with incorrect or missing setup info.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: empty setup file',
  'failure',
  $msopck,
  "setup_bad_empty.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOINSTRUMENTID)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no LSK_FILE_NAME keyword',
  'failure',
  $msopck,
  "setup_bad_no_lsk.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOSLKFILENAME)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no SCLK_FILE_NAME keyword',
  'failure',
  $msopck,
  "setup_bad_no_sclk.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(NOSCLKFILENAMES)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: both SCLK keywords',
  'failure',
  $msopck,
  "setup_bad_two_sclks.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(TWOSCLKFILENAMES)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no CK_TYPE keyword',
  'failure',
  $msopck,
  "setup_bad_no_ck_type.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOCKSEGMENTTYPE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no INSTRUMENT_ID keyword',
  'failure',
  $msopck,
  "setup_bad_no_inst_id.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOINSTRUMENTID)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no REFERENCE_FRAME_NAME keyword',
  'failure',
  $msopck,
  "setup_bad_no_ref_frame.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOFRAMENAME)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no ANGULAR_RATE_PRESENT keyword',
  'failure',
  $msopck,
  "setup_bad_no_rate_flag.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOANGULARRATEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no INPUT_TIME_TYPE keyword',
  'failure',
  $msopck,
  "setup_bad_no_time_type.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOTIMETYPEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no INPUT_DATA_TYPE keyword',
  'failure',
  $msopck,
  "setup_bad_no_data_type.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NODATATYPEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no EULER_ANGLE_UNITS keyword',
  'failure',
  $msopck,
  "setup_bad_no_ang_units.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOEULERANGLEUNITS)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no EULER_ROTATIONS_ORDER keyword',
  'failure',
  $msopck,
  "setup_bad_no_rot_order.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(NOROTATIONORDER)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no OFFSET_ROTATION_AXES keyword',
  'failure',
  $msopck,
  "setup_bad_no_offset_axes.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOOFFSETANGLEAXES)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no OFFSET_ROTATION_UNITS keyword',
  'failure',
  $msopck,
  "setup_bad_no_offset_units.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOOFFSETANGLEUNITS)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: no PRODUCER_ID keyword',
  'failure',
  $msopck,
  "setup_bad_no_producer.txt input_good_ang_av.txt ck_failure.bc",
  16,
  'SPICE(NOPRODUCERID)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: nonexistent LSK',
  'failure',
  $msopck,
  "setup_bad_lsk_nonexistent.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOSUCHFILE)',
  'MSOPCK --> FURNSH --> ZZLDKER'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: nonexistent SCLK',
  'failure',
  $msopck,
  "setup_bad_sclk_nonexistent.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOSUCHFILE)',
  'MSOPCK --> FURNSH --> ZZLDKER'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: nonexistent FK',
  'failure',
  $msopck,
  "setup_bad_fk_nonexistent.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOSUCHFILE)',
  'MSOPCK --> FURNSH --> ZZLDKER'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: unsupported CK type',
  'failure',
  $msopck,
  "setup_bad_ck_type_4.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADCKTYPESPEC)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: bad CK ID',
  'failure',
  $msopck,
  "setup_bad_ck_id_positive.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADINSTRUMENTID)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: unknown reference frame',
  'failure',
  $msopck,
  "setup_bad_frame_unknown.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(UNRECOGNIZEDFRAME)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid rate flag value',
  'failure',
  $msopck,
  "setup_bad_rate_flag_unknown.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADANGULARRATEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: negative quaternion threshold',
  'failure',
  $msopck,
  "setup_bad_quat_threshold_neg.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADQUATTHRESHOLD)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: zero quaternion threshold',
  'failure',
  $msopck,
  "setup_bad_quat_threshold_zero.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADQUATTHRESHOLD)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too big quaternion threshold',
  'failure',
  $msopck,
  "setup_bad_quat_threshold_big.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADQUATTHRESHOLD)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: negative rate threshold',
  'failure',
  $msopck,
  "setup_bad_rate_threshold_neg.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADRATETHRESHOLD)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: zero rate threshold',
  'failure',
  $msopck,
  "setup_bad_rate_threshold_zero.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADRATETHRESHOLD)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too few elements for rate threshold',
  'failure',
  $msopck,
  "setup_bad_rate_threshold_two.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADANGRATEERROR)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too many elements for rate threshold',
  'failure',
  $msopck,
  "setup_bad_rate_threshold_four.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADANGRATEERROR)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid time type',
  'failure',
  $msopck,
  "setup_bad_time_type_unknown.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADTIMETYPEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid data type',
  'failure',
  $msopck,
  "setup_bad_data_type_unknown.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADDATATYPEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: unsupported units',
  'failure',
  $msopck,
  "setup_bad_angle_units_unknown.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADEULERANGLEUNITS)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too few rotation order elements',
  'failure',
  $msopck,
  "setup_bad_rotation_order_two.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADROTATIONSORDER)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too many rotation order elements',
  'failure',
  $msopck,
  "setup_bad_rotation_order_four.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADROTATIONSORDER)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: mixed CH/DP axis specification',
  'failure',
  $msopck,
  "setup_bad_rotation_order_mixed.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADROTATIONAXISXYZ)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid axis letter',
  'failure',
  $msopck,
  "setup_bad_rotation_order_not_xyz.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADROTATIONAXISXYZ)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid axis index',
  'failure',
  $msopck,
  "setup_bad_rotation_order_not_123.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADROTATIONAXIS123)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid rotation type',
  'failure',
  $msopck,
  "setup_bad_rotation_type_unknown.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADROTATIONTYPE)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid rate frame spec',
  'failure',
  $msopck,
  "setup_bad_rate_frame_unknown.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADRATEFRAMEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too few offset angles',
  'failure',
  $msopck,
  "setup_bad_offset_angles_two.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADOFFSETANGLES)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too many offset angles',
  'failure',
  $msopck,
  "setup_bad_offset_angles_four.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADOFFSETANGLES)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too few offset axes',
  'failure',
  $msopck,
  "setup_bad_offset_axes_two.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOOFFSETANGLEAXES)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: too many offset axes',
  'failure',
  $msopck,
  "setup_bad_offset_axes_four.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NOOFFSETANGLEAXES)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: mixed CH/DP offset axes spec',
  'failure',
  $msopck,
  "setup_bad_offset_axes_mixed.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADOFFSETAXISXYZ)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid offset axis letter',
  'failure',
  $msopck,
  "setup_bad_offset_axes_not_xyz.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADOFFSETAXISXYZ)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid offset axis index',
  'failure',
  $msopck,
  "setup_bad_offset_axes_not_123.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADOFFSETAXIS123)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid offset rotation units',
  'failure',
  $msopck,
  "setup_bad_offset_units_unknown.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(BADOFFSETANGUNITS)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: negative downsample tolerance',
  'failure',
  $msopck,
  "setup_bad_down_sample_neg.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(BADDOWNSAMPLINGTOL)',
  'MSOPCK --> CK3SDN'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: invalid table flag',
  'failure',
  $msopck,
  "setup_bad_inlude_table_unknown.txt input_good_ang_av.txt ck_failure.bc",
  19,
  'SPICE(BADTABLEFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: unquoted LSK name',
  'failure',
  $msopck,
  "setup_bad_misformatted_lsk.txt input_good_ang_av.txt ck_failure.bc",
  19,
  'SPICE(NUMBEREXPECTED)',
  'MSOPCK --> FURNSH --> ZZLDKER --> LDPOOL --> ZZRVAR'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: mixed numeric/char value',
  'failure',
  $msopck,
  "setup_bad_misformatted_order.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(TYPEMISMATCH)',
  'MSOPCK --> FURNSH --> ZZLDKER --> LDPOOL --> ZZRVAR'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: array value without ()',
  'failure',
  $msopck,
  "setup_bad_misformatted_ck_type.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(NUMBEREXPECTED)',
  'MSOPCK --> FURNSH --> ZZLDKER --> LDPOOL --> ZZRVAR'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: make up rates without averaging for CK1',
  'failure',
  $msopck,
  "setup_bad_make_rates_na_ck1.txt input_good_ang_av.txt ck_failure.bc",
  18,
  'SPICE(NARATESFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: make up rates with veraging for CK1',
  'failure',
  $msopck,
  "setup_bad_make_rates_av_ck1.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(NARATESFLAG)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: request to make fake SCLK that already exists',
  'failure',
  $msopck,
  "setup_bad_existing_fake_sclk.txt input_good_ang_av.txt ck_failure.bc",
  17,
  'SPICE(FAKESCLKEXISTS)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: request to make fake SCLK that already exists',
  'failure',
  $msopck,
  "setup_bad_no_av_ck2.txt input_good_ang_only.txt ck_failure.bc",
  19,
  'SPICE(NORATESFORTYPE2CK)'
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad setup: nonexistent comments file',
  'failure',
  $msopck,
  "setup_bad_nonexistent_comments.txt input_good_ang_only.txt ck_failure2.bc",
  17,
  'SPICE(NOCOMMENTSFILE)'
);

#
# Delete "failure" CK if it exists.
#
if ( $deleteck eq "yes" && -e "ck_failure.bc" ) { unlink( "ck_failure.bc" ) };

#
# Delete test data if post-run cleanup was requested.
#
if ( $postruncleanup eq "yes" ) {
  print "\n";
  print "Cleaning up ...\n";
  print "\n";
  &test_data( "delete" );
}

#
# All done.
#
print "\n";
print "Total: $counttotal --- Passed: $countpass  --- Failed: $countfail\n";
print "\n";

exit;

#
# This routine runs the specified test and prints results to the screen.
#
sub run_test {

  #
  # All argument are inputs. Output is via displaying report message to
  # the screen. Arguments are:
  #
  #    $reporttype  -- lists all types of info to be included into the report
  #                    (possible values are "command", "output", "expvalues")
  #    $maxtocompare - maximum number of characters from each @expvalue line
  #                    to check in inputs; if "", check complete lines
  #    $shortonly   -- flag indicating whether only 'SPICE(...)' line from
  #                    @expvalue should be checked in the output for 
  #                    failure-type cases; "yes" or "no"
  #    $checkcount  -- flag indicating whether the count of output lines
  #                    should be checked; "yes" or "no"
  #    $logname     -- the name of a log file, the contents of which should be
  #                    checked instead of captured STDOUT output; if "",
  #                    STDOUT is checked
  #    $testdesc    -- text line describing test
  #    $testtype    -- "success" or "failure" for expected status 0 or non 0
  #    $progname    -- name of program to run
  #    $commandline -- complete command line
  #    $expcount    -- expected count of output lines
  #    @expvalue    -- an array of strings to look for in the output.
  #                    "?" in these string stands for "any one character".
  #
  ( $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
    $testdesc,
    $testtype,
    $progname,
    $commandline,
    $expcount,
    @expvalue ) = @_;
  $infotypes = $reporttype;
  $report = "";

  $counttotal++;

  #
  # Run the test and save screen output.
  #
  $result = `$progname $commandline 2>&1`;

  #
  # Check exit status vs expected status and reflect then in the report.
  #
  $status = ( $? >> 8 );
  if (    ( ( ! $status ) && $testtype eq "success" ) ||
          ( (   $status ) && $testtype eq "failure" )    ) {
    #
    # Expected status matches returned status. Good.
    #
    $report = "";
  } elsif ( ( ! $status ) && $testtype eq "failure" ) {
    #
    # Expected failure, got success. Bad.
    #
    $report = "\n   ERROR: expected failure but returned with success.\n ";
  } elsif ( (   $status ) && $testtype eq "success" ) {
    #
    # Expected success, got failure. Bad.
    #
    $report = "\n   ERROR: expected success but returned with failure.\n ";
  }

  #
  # Check that output has expected number of lines.
  #
  if ( $checkcount eq "yes" ) {
    $rescount = 0;
    while( $result =~ m/\n/g ) {
      $rescount++;
    }
    if ( $rescount != $expcount ) {
      $report = $report.
      "\n   ERROR: expected $expcount output lines but got $rescount.\n";
    }
  }

  #
  # Check that each of expected lines is present in the output.
  #
  $checkedcount = 0;

  for ($i = 0; $i <= $#expvalue; $i++ ) {

    #
    # Take all or a part of expected value based on $maxtocompare.
    #
    if ( $maxtocompare eq "" ) {
      $shortexpvalue = $expvalue[$i];
    } else {
      $shortexpvalue = substr( $expvalue[$i], 0, $maxtocompare );
    }

    #
    # Pre-process expected value to escape all special regex characters
    # except "?" which, from this routine's point of view, stands for
    # "any one character" and, therefore, get replaced with ".".
    #
    $modexpvalue = $shortexpvalue;
    $modexpvalue =~ s/\\/\\\\/g;
    $modexpvalue =~ s/\n/\\n/g;
    $modexpvalue =~ s/\./\\./g;
    $modexpvalue =~ s/\^/\\^/g;
    $modexpvalue =~ s/\$/\\\$/g;
    $modexpvalue =~ s/\*/\\*/g;
    $modexpvalue =~ s/\+/\\+/g;
    $modexpvalue =~ s/\{/\\{/g;
    $modexpvalue =~ s/\}/\\}/g;
    $modexpvalue =~ s/\[/\\[/g;
    $modexpvalue =~ s/\]/\\]/g;
    $modexpvalue =~ s/\(/\\(/g;
    $modexpvalue =~ s/\)/\\)/g;
    $modexpvalue =~ s/\|/\\|/g;

    $modexpvalue =~ s/\?/\./g;

    #
    # Check if the output contained expected string. First, make an exception
    # for failure-type runs checking only short error messages.
    #
    if ( $testtype  eq "failure" &&
         $shortonly eq "yes"     &&
         ! ( $shortexpvalue =~ /^SPICE\(.+\)$/ ) ) {

      #
      # Don't check this line because it is not a short error message.
      #

    } else {

      if ( $result =~ /$modexpvalue/ ) {

	#
	# Expected string is present in the output. Good.
	#

      } else {

	#
	# Expected string is NOT present in the output. Bad.
	#
	$report = $report.
	 "\n   ERROR: expected string '$shortexpvalue' was not in the output.\n";

      }

      $checkedcount++;

    }

  }

  #
  # Safety belt against poor test setups: verify that we checked at
  # least one line.
  #
  if ( $checkedcount == "0" ) {
    $report = $report.
      "\n   ERROR: bad test case setup: no lines from expected values were checked.\n";
  }

  #
  # Finalize report.
  #
  if ( $report eq "" ) {

    $countpass++;
    $report = "--- passed --- ($testtype) $testdesc\n";

  } else {

    $countfail++;
    $report = "\n".
              "--- FAILED --- ($testtype) $testdesc\n".
              "$report";

    $infotypes = "command output expvalues";

  }

  #
  # Add additonal information to the report as needed.
  #
  if ( $infotypes =~ /command/ ) {
    $report = "$report".
              "\n".
              "   COMMAND --- \n".
              "\n".
              "$progname $commandline\n".
              "\n";
  }

  if ( $infotypes =~ /output/ ) {
    $report = "$report".
              "\n".
              "   OUTPUT --- \n".
              "\n".
              "$result\n".
              "\n";
  }

  if ( $infotypes =~ /expvalues/ ) {
    $report = "$report".
              "\n".
              "   EXPECTED VALUES --- \n".
              "\n";

    for ($i = 0; $i <= $#expvalue; $i++ ) {
      if ( $maxtocompare eq "" ) {
	$report = "$report".
	          "$expvalue[$i]\n";
      } else {
	$report = "$report".
	          substr( $expvalue[$i], 0, $maxtocompare )."\n";
      }
    }
    $report = "$report\n";
  }

  #
  # Display report.
  #
  print $report;

}

#
# This routine generates all necessary kernels.
#
sub test_data {

  #
  # The only input is action ("make" or "delete"). Outputs are files
  # needed for the test.
  #
  ( $action ) = @_;
  $myaction = $action;

  #
  # The following files will be made
  #
  #   lsk_good.tls --- baseline LSK (a copy of naif0008.tls)
  #
  #   lsk_bad_empty.tls --- LSK with no data
  #
  #   sclk_good_999.tsc --- baseline SCLK, counts ET milliseconds from J2000
  #
  #   sclk_good_999_average_rate.tsc --- different SCLK rates; for averaging
  #
  #   sclk_good_888.tsc --- same as sclk_good_999.tsc but for ID -888
  #
  #   sclk_bad_999_empty.tsc --- SCLK with no data
  #
  #   sclk_bad_999_type_ne_1.tsc --- SCLK with type 2 (error for DSCLK)
  #
  #   sclk_bad_999_one_field.tsc --- SCLK with one field (error for DSCLK)
  #
  #   sclk_bad_999_one_moduli.tsc --- one element in MODULI (error for DSCLK)
  #
  #   sclk_bad_999_one_offset.tsc --- one element in OFFSETS (error for DSCLK)
  #
  #   sclk_bad_999_no_coeffs.tsc --- without COEFFICIENTS (error for CK2)
  #
  #   sclk_bad_999_no_moduli.tsc --- without MODULI (error for CK2)
  #
  #   sclk_bad_999_zero_moduli.tsc --- with zero moduli (error for CK2)
  #
  #   fk_good.tf --- baseline FK (two frames: CK and reference)
  #
  #   fk_good_no_ck_sclk.tf --- baseline without CK_..._SCLK keyword
  #
  #   fk_good_ck_sclk_888.tf --- baseline with CK_..._SCLK = -888
  #
  #   fk_bad_empty.tf --- FK with no data
  #
  #   comments_good.txt --- baseline comment file
  #
  #   comments_good_with_tabs.txt --- comments with TABs
  #
  #   comments_good_empty.txt --- empty comment file
  #
  #   input_good_ang_av.txt --- baseline input; angles (deg)  and AVs
  #
  #   input_good_ang_av.txt --- baseline input with extra points for downsampling
  #
  #   input_good_ang_only.txt --- baseline; angles (deg) only
  #
  #   input_good_ang_radians_av.txt --- baseline input; angles (rad)  and AVs
  #
  #   input_good_squat_av.txt --- baseline input; SPICE quats and AVs
  #
  #   input_good_squat_av_qfilter.txt --- baseline input; SPICE quats and AVs; for filtering
  #
  #   input_good_mquat_av.txt --- baseline input; MSOP quats and AVs
  #
  #   input_good_mat_av.txt --- baseline input; matrices and AVs
  #
  #   input_good_ang_av_twotimes.txt --- 2 times for CK2; ang/av
  #
  #   input_good_ang_av_ticks.txt --- baseline w. ticks; ang/av
  #
  #   input_good_ang_av_sclkstr.txt --- baseline w. SCLK string; ang/av
  #
  #   input_good_ang_av_utc.txt --- baseline w. UTC; ang/av
  #
  #   input_good_ang_av_ticks_twotimes.txt --- 2 times/ticks; ang/av
  #
  #   input_good_ang_av_sclkstr_twotimes.txt --- 2 times/SCLK string; ang/av
  #
  #   input_good_ang_av_utc_twotimes.txt --- 2 times/UTC; ang/av
  #
  #   input_good_better_ang_body.txt --- better input with angles in 'BODY' order
  #
  #   input_good_better_ang_rad.txt  --- better input with angles in radians
  #
  #   input_good_better_ang_space.txt --- better input with angles in 'SPACE' order
  #
  #   input_good_better_rate_inst.txt --- better input with rates in 'INSTRUMENT' frame
  #
  #   input_good_better_mat.txt --- better input as matrixes
  #
  #   input_good_better_squat.txt --- better input as SPICE quats
  #
  #   input_good_better_mquat.txt --- better input as MSOP quats
  #
  #   input_good_large_nbuff_m1.txt --- large input, NBUFF-1 points (for 1 seg)
  #
  #   input_good_large_nbuff.txt --- large input, NBUFF points (for 1 seg)
  #
  #   input_good_large_nbuff_p1.txt --- large input, NBUFF+1 points (for 2 seg)
  #
  #   input_good_large_2nbuff.txt --- large input, 2*NBUFF points (for 3 seg)
  #
  #   input_good_one_point.txt --- input with only one point
  #
  #   setup_good_1_sclk_ang_av_all.txt --- baseline sclk/angle/ck1/av setup
  #
  #   setup_good_1_sclk_ang_av_req.txt --- baseline with only required keywords
  #
  #   setup_good_1_sclk_ang_noav_all.txt --- baseline sclk/angle/ck1/noav setup
  #
  #   setup_good_3_sclk_ang_av_all.txt --- baseline sclk/angle/ck3/av setup
  #
  #   setup_good_3_sclk_ang_av_rfilter1.txt --- with rate filtering (basic input)
  #
  #   setup_good_3_sclk_ang_av_rfilter2.txt --- with rate filtering (better input)
  #
  #   setup_good_3_sclk_ang_av_tabcmt.txt --- comments with tabs
  #
  #   setup_good_3_sclk_ang_av_empcmt.txt --- empty comments
  #
  #   setup_good_3_sclk_ang_av_timecor.txt --- with time correction
  #
  #   setup_good_3_sclk_ang_av_sclk888.txt --- for SCLK 888
  #
  #   setup_good_3_sclk_ang_av_fsclk999.txt --- for fake SCLK 999
  #
  #   setup_good_3_sclk_ang_av_fsclk888.txt --- for fake SCLK 888
  #
  #   setup_good_3_sclk_ang_av_dsmpl.txt --- with down sampling = 0.001
  #
  #   setup_good_3_sclk_ang_av_tol1.txt --- with tol = 1 (for all singletons)
  #
  #   setup_good_3_sclk_ang_av_tol50.txt --- with tol = 50 (for some gaps)
  #
  #   setup_good_3_sclk_ang_maav_tol1.txt --- with tol = 1 (for all singletons)/MAKE UP
  #
  #   setup_good_3_sclk_ang_maav_tol50.txt --- with tol = 50 (for some gaps)/MAKE UP
  #
  #   setup_good_3_sclk_ang_mana_tol1.txt --- with tol = 1 (for all singletons)/MAKE UP/NA
  #
  #   setup_good_3_sclk_ang_mana_tol50.txt --- with tol = 50 (for some gaps)/MAKE UP/NA
  #
  #   setup_good_3_sclk_ang_av_axes123.txt --- with axes as 123
  #
  #   setup_good_3_sclk_ang_av_inst.txt --- baseline sclk/angle/ck3/av(INST) setup
  #
  #   setup_good_3_sclk_ang_av_offsetdeg.txt --- baseline w. offset in deg
  #
  #   setup_good_3_sclk_ang_av_offsetrad.txt --- baseline w. offset in deg
  #
  #   setup_good_3_sclk_ang_av_offset123.txt --- baseline w. offset axes 123
  #
  #   setup_good_3_sclk_ang_av_body.txt --- baseline sclk/angle(BODY)/ck3/av setup
  #
  #   setup_good_3_sclk_angrad_av_all.txt --- sclk/angle(rad)/ck3/av setup
  #
  #   setup_good_3_sclk_ang_noav_all.txt --- baseline sclk/angle/ck3/noav setup
  #
  #   setup_good_3_dsclk_ang_av_all.txt --- baseline dsclk/angle/ck3/av setup
  #
  #   setup_good_3_et_ang_av_all.txt --- baseline et/angle/ck3/av setup
  #
  #   setup_good_3_ticks_ang_av_all.txt --- baseline ticks/angle/ck3/av setup
  #
  #   setup_good_3_utc_ang_av_all.txt --- baseline utc/angle/ck3/av setup
  #
  #   setup_good_2_sclk_ang_av_all.txt --- baseline sclk/angle/ck2/av setup
  #
  #   setup_good_2_avg_sclk_rates.txt --- with varying SCLK rates for averging check
  #
  #   setup_good_2_dsclk_ang_av_all.txt --- baseline dsclk/angle/ck2/av setup
  #
  #   setup_good_2_et_ang_av_all.txt --- baseline et/angle/ck2/av setup
  #
  #   setup_good_2_ticks_ang_av_all.txt --- baseline ticks/angle/ck2/av setup
  #
  #   setup_good_2_utc_ang_av_all.txt --- baseline utc/angle/ck2/av setup
  #
  #   setup_good_3_sclk_squat_av_all.txt --- baseline sclk/SPICEq/ck3/av setup
  #
  #   setup_good_3_sclk_squat_av_qfilter.txt --- with quat filter
  #
  #   setup_good_3_sclk_mquat_av_all.txt --- baseline sclk/MSOPq/ck3/av setup
  #
  #   setup_good_3_sclk_mat_av_all.txt --- baseline sclk/matrices/ck3/av setup
  #
  #   setup_good_3_sclk_mat_av_req.txt --- baseline with only required keywords
  #
  #   setup_good_3_sclk_ang_maav_all.txt --- sclk/ang/ck3/MAKE UP setup
  #
  #   setup_good_3_sclk_ang_mana_all.txt --- sclk/ang/ck3/MAKE UP/NA setup
  #
  #   setup_good_2_sclk_ang_maav_all.txt --- sclk/ang/ck2/MAKE UP setup
  #
  #   setup_good_2_sclk_ang_mana_all.txt --- sclk/ang/ck2/MAKE UP/NA setup
  #
  #   setup_good_2_sclk_ang_mana_tol1.txt --- with tol=1 for singleton intervals
  #
  #   setup_good_2_sclk_ang_mana_tol50.txt --- with tol=50 for a few gaps
  #
  #   setup_bad_empty.txt --- empty setup file
  #
  #   setup_bad_no_lsk.txt --- no LSK_FILE_NAME keyword
  #
  #   setup_bad_no_sclk.txt --- no SCLK_FILE_NAME keyword
  #
  #   setup_bad_two_sclks.txt --- both SCLK keywords
  #
  #   setup_bad_no_ck_type.txt --- no CK_TYPE keyword
  #
  #   setup_bad_no_inst_id.txt --- no INSTRUMENT_ID keyword
  #
  #   setup_bad_no_ref_frame.txt --- no REFERENCE_FRAME_NAME keyword
  #
  #   setup_bad_no_rate_flag.txt --- no ANGULAR_RATE_PRESENT keyword
  #
  #   setup_bad_no_time_type.txt --- no INPUT_TIME_TYPE keyword
  #
  #   setup_bad_no_data_type.txt --- no INPUT_DATA_TYPE keyword
  #
  #   setup_bad_no_ang_units.txt --- no EULER_ANGLE_UNITS keyword
  #
  #   setup_bad_no_rot_order.txt --- no EULER_ROTATIONS_ORDER keyword
  #
  #   setup_bad_no_offset_axes.txt --- no OFFSET_ROTATION_AXES keyword
  #
  #   setup_bad_no_offset_units.txt --- no OFFSET_ROTATION_UNITS keyword
  #
  #   setup_bad_no_producer.txt --- no PRODUCER_ID keyword
  #
  #   setup_bad_lsk_nonexistent.txt --- nonexistent LSK
  #
  #   setup_bad_sclk_nonexistent.txt --- nonexistent SCLK
  #
  #   setup_bad_fk_nonexistent.txt --- nonexistent FK
  #
  #   setup_bad_ck_type_4.txt --- unsupported CK type
  #
  #   setup_bad_ck_id_positive.txt --- bad CK ID
  #
  #   setup_bad_frame_unknown.txt --- unknown reference frame
  #
  #   setup_bad_rate_flag_unknown.txt --- invalid rate flag value
  #
  #   setup_bad_quat_threshold_neg.txt --- negative quaternion threshold
  #
  #   setup_bad_quat_threshold_zero.txt --- zero quaternion threshold
  #
  #   setup_bad_quat_threshold_big.txtn --- too big quaternion threshold
  #
  #   setup_bad_rate_threshold_neg.txt --- negative rate threshold
  #
  #   setup_bad_rate_threshold_zero.txt --- zero rate threshold
  #
  #   setup_bad_rate_threshold_two.txt --- too few elements rate threshold
  #
  #   setup_bad_rate_threshold_four.txt --- too many elements rate threshold
  #
  #   setup_bad_time_type_unknown.txt --- invalid time type
  #
  #   setup_bad_data_type_unknown.txt --- invalid data type
  #
  #   setup_bad_angle_units_unknown.txt --- unsupported units
  #
  #   setup_bad_rotation_order_two.txt --- too few rotation order elements
  #
  #   setup_bad_rotation_order_four.txt --- too many rotation order elements
  #
  #   setup_bad_rotation_order_mixed.txt --- mixed CH/DP specification
  #
  #   setup_bad_rotation_order_not_xyz.txt --- invalid axis letter
  #
  #   setup_bad_rotation_order_not_123.txt --- invalid axis index
  #
  #   setup_bad_rotation_type_unknown.txt --- invalid rotation type
  #
  #   setup_bad_rate_frame_unknown.txt --- invalid rate frame spec
  #
  #   setup_bad_offset_angles_two.txt --- too few offset angles
  #
  #   setup_bad_offset_angles_four.txt --- t00 many offset angles
  #
  #   setup_bad_offset_axes_two.txt --- too few offset axes
  #
  #   setup_bad_offset_axes_four.txt --- too many offset axes
  #
  #   setup_bad_offset_axes_mixed.txt --- mixed CH/DP axes spec
  #
  #   setup_bad_offset_axes_not_xyz.txt --- invalid axis letter
  #
  #   setup_bad_offset_axes_not_123.txt --- invalid axis index
  #
  #   setup_bad_offset_units_unknown.txt --- invalid units
  #
  #   setup_bad_down_sample_neg.txt --- negative downsample tolerance
  #
  #   setup_bad_inlude_table_unknown.txt --- invalid table flag
  #
  #   setup_bad_misformatted_lsk.txt --- unquoted LSK name
  #
  #   setup_bad_misformatted_order.txt --- mixes numeric/char value
  #
  #   setup_bad_misformatted_ck_type.txt --- list without ().
  #
  #   setup_bad_empty_lsk.txt --- using empty LSK
  #
  #   setup_bad_empty_sclk.txt --- using empty SCLK
  #
  #   setup_bad_empty_fk.txt --- using empty FK
  #
  #   setup_bad_sclk_not_type_1.txt --- not type 1 SCLK with DSCLK times
  #
  #   setup_bad_sclk_one_field.txt --- not two field SCLK with DSCLK times
  #
  #   setup_bad_sclk_one_moduli.txt --- not two moduli SCLK with DSCLK times
  #
  #   setup_bad_sclk_one_offset.txt --- not two offsets SCLK with DSCLK times
  #
  #   setup_bad_sclk_no_coeffs.txt --- SCLK without COEFF; error for CK2
  #
  #   setup_bad_sclk_no_moduli.txt --- SCLK without MODULI; error for CK2
  #
  #   setup_bad_sclk_zero_moduli.txt --- SCLK with zero moduli; error for CK2
  #
  #   setup_bad_make_rates_na_ck1.txt --- make up rates/NA; error for CK1
  #
  #   setup_bad_make_rates_av_ck1.txt --- make up rates/AVERG.; error for CK1
  #
  #   setup_bad_existing_fake_sclk.txt --- points to existing fake SCLK
  #
  #   setup_bad_no_av_ck2.txt --- NO avs for CK2
  #
  #   setup_bad_nonexistent_comments.txt --- nonexistent comments file
  #
  #   input_bad_empty.txt --- empty input file
  #
  #   input_bad_blank_line_all.txt --- input file with all blank lines
  #
  #   input_bad_blank_line_leading.txt --- input with leading blank line
  #
  #   input_bad_blank_line_trailing.txt --- input with trailing blank line
  #
  #   input_bad_blank_line_middle.txt --- input with blank line in the middle
  #
  #   input_bad_delimited_tab.txt --- tab delimited input
  #
  #   input_bad_delimited_comma.txt --- comma delimited input
  #
  #   input_bad_time_numeric.txt --- bad start time (SCLK/DSCLK/ET/TICKS)
  #
  #   input_bad_time_utc.txt --- bad start time (UTC)
  #
  #   input_bad_time_numeric_stop.txt --- bad stop time (SCLK/DSCLK/ET/TICKS)
  #
  #   input_bad_time_utc_stop.txt --- bad stop time (UTC)
  #
  #   input_bad_angle_numeric_1.txt --- bad angle, element 1
  #
  #   input_bad_angle_numeric_2.txt --- bad angle, element 2
  #
  #   input_bad_angle_numeric_3.txt --- bad angle, element 3
  #
  #   input_bad_angle_too_few_1.txt --- too few angles, only 1
  #
  #   input_bad_angle_too_few_2.txt --- too few angles, only 2
  #
  #   input_bad_rate_numeric_1.txt --- bad rate, element 1
  #
  #   input_bad_rate_numeric_2.txt --- bad rate, element 2
  #
  #   input_bad_rate_numeric_3.txt --- bad rate, element 3
  #
  #   input_bad_rate_too_few_1.txt --- too few rate elements, only 1
  #
  #   input_bad_rate_too_few_2.txt --- too few rate elements, only 2
  #
  #   input_bad_squat_numeric_1.txt --- bad SPICE quat, element 1
  #
  #   input_bad_squat_numeric_2.txt --- bad SPICE quat, element 2
  #
  #   input_bad_squat_numeric_3.txt --- bad SPICE quat, element 3
  #
  #   input_bad_squat_numeric_4.txt --- bad SPICE quat, element 4
  #
  #   input_bad_squat_too_few_1.txt --- too few SPICE quat elements, only 1
  #
  #   input_bad_squat_too_few_2.txt --- too few SPICE quat elements, only 2
  #
  #   input_bad_squat_too_few_3.txt --- too few SPICE quat elements, only 3
  #
  #   input_bad_mquat_numeric_1.txt --- bad MSOP quat, element 1
  #
  #   input_bad_mquat_numeric_2.txt --- bad MSOP quat, element 2
  #
  #   input_bad_mquat_numeric_3.txt --- bad MSOP quat, element 3
  #
  #   input_bad_mquat_numeric_4.txt --- bad MSOP quat, element 4
  #
  #   input_bad_mquat_too_few_1.txt --- too few MSOP quat elements, only 1
  #
  #   input_bad_mquat_too_few_2.txt --- too few MSOP quat elements, only 2
  #
  #   input_bad_mquat_too_few_3.txt --- too few MSOP quat elements, only 3
  #
  #   input_bad_mat_numeric_1.txt --- bad matrix, element 1
  #
  #   input_bad_mat_numeric_2.txt --- bad matrix, element 2
  #
  #   input_bad_mat_numeric_3.txt --- bad matrix, element 3
  #
  #   input_bad_mat_numeric_4.txt --- bad matrix, element 4
  #
  #   input_bad_mat_numeric_5.txt --- bad matrix, element 5
  #
  #   input_bad_mat_numeric_6.txt --- bad matrix, element 6
  #
  #   input_bad_mat_numeric_7.txt --- bad matrix, element 6
  #
  #   input_bad_mat_numeric_8.txt --- bad matrix, element 8
  #
  #   input_bad_mat_numeric_9.txt --- bad matrix, element 9
  #
  #   input_bad_mat_too_few_1.txt --- too few matrix elements, only 1
  #
  #   input_bad_mat_too_few_2.txt --- too few matrix elements, only 2
  #
  #   input_bad_mat_too_few_3.txt --- too few matrix elements, only 3
  #
  #   input_bad_mat_too_few_4.txt --- too few matrix elements, only 4
  #
  #   input_bad_mat_too_few_5.txt --- too few matrix elements, only 5
  #
  #   input_bad_mat_too_few_6.txt --- too few matrix elements, only 6
  #
  #   input_bad_mat_too_few_7.txt --- too few matrix elements, only 7
  #
  #   input_bad_mat_too_few_8.txt --- too few matrix elements, only 8
  #
  #   input_bad_duplicate_times.txt --- duplicate time tags
  #
  #   input_bad_quats_nonunit_all.txt --- all quats are filtered out
  #
  #   input_bad_too_large_avs.txt --- all avs are filtered out
  #
  @files = (
            "lsk_good.tls",
            "lsk_bad_empty.tls",
            "sclk_good_999.tsc",
            "sclk_good_999_average_rate.tsc",
            "sclk_good_888.tsc",
            "sclk_bad_999_empty.tsc",
            "sclk_bad_999_type_ne_1.tsc",
            "sclk_bad_999_one_field.tsc",
            "sclk_bad_999_one_moduli.tsc",
            "sclk_bad_999_one_offset.tsc",
            "sclk_bad_999_no_coeffs.tsc",
            "sclk_bad_999_no_moduli.tsc",
            "sclk_bad_999_zero_moduli.tsc",
            "fk_good.tf",
            "fk_good_no_ck_sclk.tf",
            "fk_good_ck_sclk_888.tf",
            "fk_bad_empty.tf",
            "comments_good.txt",
            "comments_good_with_tabs.txt",
            "comments_good_empty.txt",
            "input_good_ang_av.txt",
            "input_good_ang_av_dsmpl.txt",
            "input_good_ang_only.txt",
            "input_good_ang_radians_av.txt",
            "input_good_squat_av.txt",
            "input_good_squat_av_qfilter.txt",
            "input_good_mquat_av.txt",
            "input_good_mat_av.txt",
            "input_good_ang_av_twotimes.txt",
            "input_good_ang_av_ticks.txt",
            "input_good_ang_av_sclkstr.txt",
            "input_good_ang_av_utc.txt",
            "input_good_ang_av_ticks_twotimes.txt",
            "input_good_ang_av_sclkstr_twotimes.txt",
            "input_good_ang_av_utc_twotimes.txt",
            "input_good_better_ang_body.txt",
            "input_good_better_ang_rad.txt",
            "input_good_better_ang_space.txt",
            "input_good_better_rate_inst.txt",
            "input_good_better_mat.txt",
            "input_good_better_squat.txt",
            "input_good_better_mquat.txt",
            "input_good_large_nbuff_m1.txt",
            "input_good_large_nbuff.txt",
            "input_good_large_nbuff_p1.txt",
            "input_good_large_2nbuff.txt",
            "input_good_one_point.txt",
            "setup_good_1_sclk_ang_av_all.txt",
            "setup_good_1_sclk_ang_av_req.txt",
            "setup_good_1_sclk_ang_noav_all.txt",
            "setup_good_3_sclk_ang_av_all.txt",
            "setup_good_3_sclk_ang_av_rfilter1.txt",
            "setup_good_3_sclk_ang_av_rfilter2.txt",
            "setup_good_3_sclk_ang_av_tabcmt.txt",
            "setup_good_3_sclk_ang_av_empcmt.txt",
            "setup_good_3_sclk_ang_av_timecor.txt",
            "setup_good_3_sclk_ang_av_sclk888.txt",
            "setup_good_3_sclk_ang_av_fsclk999.txt",
            "setup_good_3_sclk_ang_av_fsclk888.txt",
            "setup_good_3_sclk_ang_av_dsmpl.txt",
            "setup_good_3_sclk_ang_av_tol1.txt",
            "setup_good_3_sclk_ang_av_tol50.txt",
            "setup_good_3_sclk_ang_maav_tol1.txt",
            "setup_good_3_sclk_ang_maav_tol50.txt",
            "setup_good_3_sclk_ang_mana_tol1.txt",
            "setup_good_3_sclk_ang_mana_tol50.txt",
            "setup_good_3_sclk_ang_av_axes123.txt",
            "setup_good_3_sclk_ang_av_inst.txt",
            "setup_good_3_sclk_ang_av_offsetdeg.txt",
            "setup_good_3_sclk_ang_av_offsetrad.txt",
            "setup_good_3_sclk_ang_av_offset123.txt",
            "setup_good_3_sclk_ang_av_body.txt",
            "setup_good_3_sclk_angrad_av_all.txt",
            "setup_good_3_sclk_ang_noav_all.txt",
            "setup_good_3_dsclk_ang_av_all.txt",
            "setup_good_3_et_ang_av_all.txt",
            "setup_good_3_ticks_ang_av_all.txt",
            "setup_good_3_utc_ang_av_all.txt",
            "setup_good_2_sclk_ang_av_all.txt",
            "setup_good_2_dsclk_ang_av_all.txt",
            "setup_good_2_avg_sclk_rates.txt",
            "setup_good_2_et_ang_av_all.txt",
            "setup_good_2_ticks_ang_av_all.txt",
            "setup_good_2_utc_ang_av_all.txt",
            "setup_good_3_sclk_squat_av_all.txt",
            "setup_good_3_sclk_squat_av_qfilter.txt",
            "setup_good_3_sclk_mquat_av_all.txt",
            "setup_good_3_sclk_mat_av_all.txt",
            "setup_good_3_sclk_mat_av_req.txt",
            "setup_good_3_sclk_ang_maav_all.txt",
            "setup_good_3_sclk_ang_mana_all.txt",
            "setup_good_2_sclk_ang_maav_all.txt",
            "setup_good_2_sclk_ang_mana_all.txt",
            "setup_good_2_sclk_ang_mana_tol1.txt",
            "setup_good_2_sclk_ang_mana_tol50.txt",
            "setup_bad_empty.txt",
            "setup_bad_no_lsk.txt",
            "setup_bad_no_sclk.txt",
            "setup_bad_two_sclks.txt",
            "setup_bad_no_ck_type.txt",
            "setup_bad_no_inst_id.txt",
            "setup_bad_no_ref_frame.txt",
            "setup_bad_no_rate_flag.txt",
            "setup_bad_no_time_type.txt",
            "setup_bad_no_data_type.txt",
            "setup_bad_no_ang_units.txt",
            "setup_bad_no_rot_order.txt",
            "setup_bad_no_offset_axes.txt",
            "setup_bad_no_offset_units.txt",
            "setup_bad_no_producer.txt",
            "setup_bad_lsk_nonexistent.txt",
            "setup_bad_sclk_nonexistent.txt",
            "setup_bad_fk_nonexistent.txt",
            "setup_bad_ck_type_4.txt",
            "setup_bad_ck_id_positive.txt",
            "setup_bad_frame_unknown.txt",
            "setup_bad_rate_flag_unknown.txt",
            "setup_bad_quat_threshold_neg.txt",
            "setup_bad_quat_threshold_zero.txt",
            "setup_bad_quat_threshold_big.txt",
            "setup_bad_rate_threshold_neg.txt",
            "setup_bad_rate_threshold_zero.txt",
            "setup_bad_rate_threshold_two.txt",
            "setup_bad_rate_threshold_four.txt",
            "setup_bad_time_type_unknown.txt",
            "setup_bad_data_type_unknown.txt",
            "setup_bad_angle_units_unknown.txt",
            "setup_bad_rotation_order_two.txt",
            "setup_bad_rotation_order_four.txt",
            "setup_bad_rotation_order_mixed.txt",
            "setup_bad_rotation_order_not_xyz.txt",
            "setup_bad_rotation_order_not_123.txt",
            "setup_bad_rotation_type_unknown.txt",
            "setup_bad_rate_frame_unknown.txt",
            "setup_bad_offset_angles_two.txt",
            "setup_bad_offset_angles_four.txt",
            "setup_bad_offset_axes_two.txt",
            "setup_bad_offset_axes_four.txt",
            "setup_bad_offset_axes_mixed.txt",
            "setup_bad_offset_axes_not_xyz.txt",
            "setup_bad_offset_axes_not_123.txt",
            "setup_bad_offset_units_unknown.txt",
            "setup_bad_down_sample_neg.txt",
            "setup_bad_inlude_table_unknown.txt",
            "setup_bad_misformatted_lsk.txt",
            "setup_bad_misformatted_order.txt",
            "setup_bad_misformatted_ck_type.txt",
            "setup_bad_empty_lsk.txt",
            "setup_bad_empty_sclk.txt",
            "setup_bad_empty_fk.txt",
            "setup_bad_sclk_not_type_1.txt",
            "setup_bad_sclk_one_field.txt",
            "setup_bad_sclk_one_moduli.txt",
            "setup_bad_sclk_one_offset.txt",
            "setup_bad_sclk_no_coeffs.txt",
            "setup_bad_sclk_no_moduli.txt",
            "setup_bad_sclk_zero_moduli.txt",
            "setup_bad_make_rates_na_ck1.txt",
            "setup_bad_make_rates_av_ck1.txt",
            "setup_bad_existing_fake_sclk.txt",
            "setup_bad_no_av_ck2.txt",
            "setup_bad_nonexistent_comments.txt",
            "input_bad_empty.txt",
            "input_bad_blank_line_all.txt",
            "input_bad_blank_line_leading.txt",
            "input_bad_blank_line_trailing.txt",
            "input_bad_blank_line_middle.txt",
            "input_bad_delimited_tab.txt",
            "input_bad_delimited_comma.txt",
            "input_bad_time_numeric.txt",
            "input_bad_time_utc.txt",
            "input_bad_time_numeric_stop.txt",
            "input_bad_time_utc_stop.txt",
            "input_bad_angle_numeric_1.txt",
            "input_bad_angle_numeric_2.txt",
            "input_bad_angle_numeric_3.txt",
            "input_bad_angle_too_few_1.txt",
            "input_bad_angle_too_few_2.txt",
            "input_bad_rate_numeric_1.txt",
            "input_bad_rate_numeric_2.txt",
            "input_bad_rate_numeric_3.txt",
            "input_bad_rate_too_few_1.txt",
            "input_bad_rate_too_few_2.txt",
            "input_bad_squat_numeric_1.txt",
            "input_bad_squat_numeric_2.txt",
            "input_bad_squat_numeric_3.txt",
            "input_bad_squat_numeric_4.txt",
            "input_bad_squat_too_few_1.txt",
            "input_bad_squat_too_few_2.txt",
            "input_bad_squat_too_few_3.txt",
            "input_bad_mquat_numeric_1.txt",
            "input_bad_mquat_numeric_2.txt",
            "input_bad_mquat_numeric_3.txt",
            "input_bad_mquat_numeric_4.txt",
            "input_bad_mquat_too_few_1.txt",
            "input_bad_mquat_too_few_2.txt",
            "input_bad_mquat_too_few_3.txt",
            "input_bad_mat_numeric_1.txt",
            "input_bad_mat_numeric_2.txt",
            "input_bad_mat_numeric_3.txt",
            "input_bad_mat_numeric_4.txt",
            "input_bad_mat_numeric_5.txt",
            "input_bad_mat_numeric_6.txt",
            "input_bad_mat_numeric_7.txt",
            "input_bad_mat_numeric_8.txt",
            "input_bad_mat_numeric_9.txt",
            "input_bad_mat_too_few_1.txt",
            "input_bad_mat_too_few_2.txt",
            "input_bad_mat_too_few_3.txt",
            "input_bad_mat_too_few_4.txt",
            "input_bad_mat_too_few_5.txt",
            "input_bad_mat_too_few_6.txt",
            "input_bad_mat_too_few_7.txt",
            "input_bad_mat_too_few_8.txt",
            "input_bad_duplicate_times.txt",
            "input_bad_quats_nonunit_all.txt",
            "input_bad_too_large_avs.txt"
           );

  #
  # Loop through the file list.
  #
  foreach $file ( @files ) {

    #
    # Check if there is anything to be done for this file. Report if
    # there is.
    #
    if (      (   -e $file && $myaction eq "make"   ) ) {

      print "--- no need to make existing $file ... \n";

    } elsif ( ( ! -e $file && $myaction eq "delete" )   ) {

      print "--- no need to delete non-existing $file ... \n";

    } elsif ( (   -e $file && $myaction eq "delete" ) ) {

      print "--- deleting $file ...\n";
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";

    } elsif ( ( ! -e $file && $myaction eq "make"   ) ) {

      print "--- creating $file ...\n";



      #----------------------------------------------------------------------
      if ( $file eq "lsk_good.tls" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/LSK
\\begindata
DELTET/DELTA_T_A       =   32.184
DELTET/K               =    1.657D-3
DELTET/EB              =    1.671D-2
DELTET/M               = (  6.239996D0   1.99096871D-7 )
DELTET/DELTA_AT        = ( 10,   \@1972-JAN-1
                           11,   \@1972-JUL-1
                           12,   \@1973-JAN-1
                           13,   \@1974-JAN-1
                           14,   \@1975-JAN-1
                           15,   \@1976-JAN-1
                           16,   \@1977-JAN-1
                           17,   \@1978-JAN-1
                           18,   \@1979-JAN-1
                           19,   \@1980-JAN-1
                           20,   \@1981-JUL-1
                           21,   \@1982-JUL-1
                           22,   \@1983-JUL-1
                           23,   \@1985-JUL-1
                           24,   \@1988-JAN-1
                           25,   \@1990-JAN-1
                           26,   \@1991-JAN-1
                           27,   \@1992-JUL-1
                           28,   \@1993-JUL-1
                           29,   \@1994-JUL-1
                           30,   \@1996-JAN-1
                           31,   \@1997-JUL-1
                           32,   \@1999-JAN-1
                           33,   \@2006-JAN-1 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "lsk_bad_empty.tls" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/LSK
\\begindata
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_good_999.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_MODULI_999        = ( 3155760000 1000 )
      SCLK01_OFFSETS_999       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_good_999_average_rate.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_MODULI_999        = ( 3155760000 1000 )
      SCLK01_OFFSETS_999       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0
                                  60.0 \@2000-JAN-01-12:01:00.000 2.0
                                 120.0 \@2000-JAN-01-12:03:00.000 6.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_good_888.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_888       = ( 1 )
      SCLK01_TIME_SYSTEM_888   = ( 1 )
      SCLK01_N_FIELDS_888      = ( 2 )
      SCLK01_MODULI_888        = ( 3155760000 1000 )
      SCLK01_OFFSETS_888       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_888  = ( 1 )
      SCLK_PARTITION_START_888 = ( 0.00000E+00 )
      SCLK_PARTITION_END_888   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_888  = ( 0.0 \@2000-JAN-01-11:59:59.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_empty.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_type_ne_1.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 2 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_MODULI_999        = ( 3155760000 1000 )
      SCLK01_OFFSETS_999       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_one_field.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 1 )
      SCLK01_MODULI_999        = ( 3155760000 1000 )
      SCLK01_OFFSETS_999       = ( 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_one_moduli.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_MODULI_999        = ( 3155760000 )
      SCLK01_OFFSETS_999       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_one_offset.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_MODULI_999        = ( 3155760000 1000 )
      SCLK01_OFFSETS_999       = ( 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_no_coeffs.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_MODULI_999        = ( 3155760000 1000 )
      SCLK01_OFFSETS_999       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_no_moduli.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_OFFSETS_999       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "sclk_bad_999_zero_moduli.tsc" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_KERNEL_ID = ( \@2006-08-28/12:00:00 )
      SCLK_DATA_TYPE_999       = ( 1 )
      SCLK01_TIME_SYSTEM_999   = ( 1 )
      SCLK01_N_FIELDS_999      = ( 2 )
      SCLK01_MODULI_999        = ( 3155760000 0 )
      SCLK01_OFFSETS_999       = ( 0 0 )
      SCLK01_OUTPUT_DELIM_999  = ( 1 )
      SCLK_PARTITION_START_999 = ( 0.00000E+00 )
      SCLK_PARTITION_END_999   = ( 3.15576E+12 )
      SCLK01_COEFFICIENTS_999  = ( 0.0 \@2000-JAN-01-12:00:00.000 1.0 )
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "fk_good.tf" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      FRAME_CK999_REFERENCE         = -999100
      FRAME_-999100_NAME            = 'CK999_REFERENCE'
      FRAME_-999100_CLASS           = 4
      FRAME_-999100_CLASS_ID        = -999100
      FRAME_-999100_CENTER          = -999
      TKFRAME_-999100_SPEC          = 'MATRIX'
      TKFRAME_-999100_RELATIVE      = 'J2000'
      TKFRAME_-999100_MATRIX        = ( 1.00000000   0.00000000  0.00000000
                                        0.00000000   1.00000000  0.00000000
                                        0.00000000   0.00000000  1.00000000 )
      FRAME_CK999_FRAME             = -999000
      FRAME_-999000_NAME            = 'CK999_FRAME'
      FRAME_-999000_CLASS           = 3
      FRAME_-999000_CLASS_ID        = -999000
      FRAME_-999000_CENTER          = -999
      CK_-999000_SCLK               = -999
      CK_-999000_SPK                = -999
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "fk_good_no_ck_sclk.tf" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      FRAME_CK999_REFERENCE         = -999100
      FRAME_-999100_NAME            = 'CK999_REFERENCE'
      FRAME_-999100_CLASS           = 4
      FRAME_-999100_CLASS_ID        = -999100
      FRAME_-999100_CENTER          = -999
      TKFRAME_-999100_SPEC          = 'MATRIX'
      TKFRAME_-999100_RELATIVE      = 'J2000'
      TKFRAME_-999100_MATRIX        = ( 1.00000000   0.00000000  0.00000000
                                        0.00000000   1.00000000  0.00000000
                                        0.00000000   0.00000000  1.00000000 )
      FRAME_CK999_FRAME             = -999000
      FRAME_-999000_NAME            = 'CK999_FRAME'
      FRAME_-999000_CLASS           = 3
      FRAME_-999000_CLASS_ID        = -999000
      FRAME_-999000_CENTER          = -999
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "fk_good_ck_sclk_888.tf" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      FRAME_CK999_REFERENCE         = -999100
      FRAME_-999100_NAME            = 'CK999_REFERENCE'
      FRAME_-999100_CLASS           = 4
      FRAME_-999100_CLASS_ID        = -999100
      FRAME_-999100_CENTER          = -999
      TKFRAME_-999100_SPEC          = 'MATRIX'
      TKFRAME_-999100_RELATIVE      = 'J2000'
      TKFRAME_-999100_MATRIX        = ( 1.00000000   0.00000000  0.00000000
                                        0.00000000   1.00000000  0.00000000
                                        0.00000000   0.00000000  1.00000000 )
      FRAME_CK999_FRAME             = -999000
      FRAME_-999000_NAME            = 'CK999_FRAME'
      FRAME_-999000_CLASS           = 3
      FRAME_-999000_CLASS_ID        = -999000
      FRAME_-999000_CENTER          = -999
      CK_-999000_SCLK               = -888
      CK_-999000_SPK                = -888
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "fk_bad_empty.tf" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "comments_good.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
Test comments.1
Test comments.2
Test comments.3
Test comments.4
Test comments.5
Test comments.6
Test comments.7
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "comments_good_with_tabs.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
Test comments.a1
\tTest comments.a2
\t\tTest comments.a3
\t\t\tTest comments.a4
\t\t\t\tTest comments.a5
\t\t\t\t\tTest comments.a6
\t\t\t\t\t\tTest comments.a7
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "comments_good_empty.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_dsmpl.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.000   0. 0 0 0.5 0 0
180.000  90. 0 0 2.0 0 0
202.500 135. 0 0 2.0 0 0
225.000 180. 0 0 2.0 0 0
247.500 225. 0 0 2.0 0 0
450.000   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_only.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0
180.0  90. 0 0
225.0 180. 0 0
270.0 270. 0 0
450.0   0. 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_radians_av.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000000000  0 0 0.00872664625997 0 0
180.0  1.57079632679490  0 0 0.03490658503989 0 0
225.0  3.14159265358979  0 0 0.03490658503989 0 0
270.0  4.71238898038469  0 0 0.00872664625997 0 0
450.0  0.00000000000000  0 0 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_squat_av.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_squat_av_qfilter.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  0.10000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.10000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_mquat_av.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_mat_av.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_twotimes.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0 175.0   0. 0 0 0.5 0 0
180.0 220.0  90. 0 0 2.0 0 0
225.0 265.0 180. 0 0 2.0 0 0
270.0 445.0 270. 0 0 0.5 0 0
450.0 455.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_ticks.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
     0.0   0. 0 0 0.5 0 0
180000.0  90. 0 0 2.0 0 0
225000.0 180. 0 0 2.0 0 0
270000.0 270. 0 0 0.5 0 0
450000.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_sclkstr.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
1/000:0   0. 0 0 0.5 0 0
1/180:0  90. 0 0 2.0 0 0
1/225:0 180. 0 0 2.0 0 0
1/270:0 270. 0 0 0.5 0 0
1/450:0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_utc.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
2000-01-01T11:58:55.8160728   0. 0 0 0.5 0 0
2000-01-01T12:01:55.8160728  90. 0 0 2.0 0 0
2000-01-01T12:02:40.8160728 180. 0 0 2.0 0 0
2000-01-01T12:03:25.8160728 270. 0 0 0.5 0 0
2000-01-01T12:06:25.8160728   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_ticks_twotimes.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
     0.0 175000.0   0. 0 0 0.5 0 0
180000.0 220000.0  90. 0 0 2.0 0 0
225000.0 265000.0 180. 0 0 2.0 0 0
270000.0 445000.0 270. 0 0 0.5 0 0
450000.0 455000.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_sclkstr_twotimes.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
1/000:0 1/175:0   0. 0 0 0.5 0 0
1/180:0 1/220:0  90. 0 0 2.0 0 0
1/225:0 1/265:0 180. 0 0 2.0 0 0
1/270:0 1/445:0 270. 0 0 0.5 0 0
1/450:0 1/455:0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_ang_av_utc_twotimes.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
2000-01-01T11:58:55.8160728 2000-01-01T12:01:50.8160728   0. 0 0 0.5 0 0
2000-01-01T12:01:55.8160728 2000-01-01T12:02:35.8160728  90. 0 0 2.0 0 0
2000-01-01T12:02:40.8160728 2000-01-01T12:03:20.8160728 180. 0 0 2.0 0 0
2000-01-01T12:03:25.8160728 2000-01-01T12:06:20.8160728 270. 0 0 0.5 0 0
2000-01-01T12:06:25.8160728 2000-01-01T12:06:30.8160728   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_better_ang_body.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
 2000.000     50.000000     30.000000     10.000000   -0.06958475    0.16643850   -0.21403045
 2060.000     40.000000     40.000000     15.000000   -0.04730743    0.17064915   -0.22519019
 2120.000     30.000000     50.000000     20.000000   -0.02707935    0.17157707   -0.23455726
 2180.000     20.000000     60.000000     25.000000   -0.02707935    0.17157707   -0.23455726
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_better_ang_rad.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
 2000.000  0.1745329252  0.5235987756  0.8726646260   -0.00121448    0.00290490   -0.00373554
 2060.000  0.2617993878  0.6981317008  0.6981317008   -0.00082567    0.00297839   -0.00393031
 2120.000  0.3490658504  0.8726646260  0.5235987756   -0.00047262    0.00299458   -0.00409380
 2180.000  0.4363323130  1.0471975512  0.3490658504   -0.00047262    0.00299458   -0.00409380
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_better_ang_space.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
 2000.000     10.000000     30.000000     50.000000   -0.06958475    0.16643850   -0.21403045
 2060.000     15.000000     40.000000     40.000000   -0.04730743    0.17064915   -0.22519019
 2120.000     20.000000     50.000000     30.000000   -0.02707935    0.17157707   -0.23455726
 2180.000     25.000000     60.000000     20.000000   -0.02707935    0.17157707   -0.23455726
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_better_rate_inst.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
 2000.000     10.000000     30.000000     50.000000    0.17869707    0.13285428   -0.16961704
 2060.000     15.000000     40.000000     40.000000    0.20101662    0.12321504   -0.16272713
 2120.000     20.000000     50.000000     30.000000    0.21975081    0.11711810   -0.15225642
 2180.000     25.000000     60.000000     20.000000    0.21975081    0.11711810   -0.15225642
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_better_mat.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
 2000.000  0.5566703992  0.6634139482 -0.5000000000 -0.6985970582  0.6995333323  0.1503837332  0.4495333323  0.2655843563  0.8528685320 -0.0012144831  0.0029048998 -0.0037355361
 2060.000  0.5868240888  0.4924038765 -0.6427876097 -0.4934416519  0.8468799065  0.1982668913  0.6419912966  0.2008303921  0.7399421117 -0.0008256705  0.0029783895 -0.0039303103
 2120.000  0.5566703992  0.3213938048 -0.7660444431 -0.2429453768  0.9447989965  0.2198463104  0.7944152633  0.0637250225  0.6040227736 -0.0004726238  0.0029945847 -0.0040937964
 2180.000  0.4698463104  0.1710100717 -0.8660254038  0.0339502423  0.9768294796  0.2113091309  0.8820951341 -0.1286845878  0.4531538935 -0.0004726238  0.0029945847 -0.0040937964
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_better_squat.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
 2000.000  0.8816280768  0.0326670129 -0.2692556411 -0.3862204035 -0.0012144831  0.0029048998 -0.0037355361
 2060.000  0.8907365080  0.0007194891 -0.3605945458 -0.2766939267 -0.0008256705  0.0029783895 -0.0039303103
 2120.000  0.8811203336 -0.0442962448 -0.4427487503 -0.1601197816 -0.0004726238  0.0029945847 -0.0040937964
 2180.000  0.8514443146 -0.0998285245 -0.5132809357 -0.0402433333 -0.0004726238  0.0029945847 -0.0040937964
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_better_mquat.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
 2000.000 -0.0326670129  0.2692556411  0.3862204035  0.8816280768 -0.0012144831  0.0029048998 -0.0037355361
 2060.000 -0.0007194891  0.3605945458  0.2766939267  0.8907365080 -0.0008256705  0.0029783895 -0.0039303103
 2120.000  0.0442962448  0.4427487503  0.1601197816  0.8811203336 -0.0004726238  0.0029945847 -0.0040937964
 2180.000  0.0998285245  0.5132809357  0.0402433333  0.8514443146 -0.0004726238  0.0029945847 -0.0040937964
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }


      if ( $doslowtests eq "yes" ) {

	#----------------------------------------------------------------------
	if ( $file eq "input_good_large_nbuff_m1.txt" ) {
	  open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
	  for ( $i = 1; $i <= 99999; $i++ ) {
	    printf OUTPUT "%d %8.3f %8.3f %8.3f\n", $i, $i*0.001, $i*(-0.002), $i*0.003;
	  }
	  close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
	}



	#----------------------------------------------------------------------
	if ( $file eq "input_good_large_nbuff.txt" ) {
	  open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
	  for ( $i = 1; $i <= 100000; $i++ ) {
	    printf OUTPUT "%d %8.3f %8.3f %8.3f\n", $i, $i*0.001, $i*(-0.002), $i*0.003;
	  }
	  close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
	}



	#----------------------------------------------------------------------
	if ( $file eq "input_good_large_nbuff_p1.txt" ) {
	  open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
	  for ( $i = 1; $i <= 100001; $i++ ) {
	    printf OUTPUT "%d %8.3f %8.3f %8.3f\n", $i, $i*0.001, $i*(-0.002), $i*0.003;
	  }
	  close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
	}



	#----------------------------------------------------------------------
	if ( $file eq "input_good_large_2nbuff.txt" ) {
	  open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
	  for ( $i = 1; $i <= 200000; $i++ ) {
	    printf OUTPUT "%d %8.3f %8.3f %8.3f\n", $i, $i*0.001, $i*(-0.002), $i*0.003;
	  }
	  close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
	}

      }



      #----------------------------------------------------------------------
      if ( $file eq "input_good_one_point.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        printf OUTPUT "777 1 2 3\n";
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_1_sclk_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 1
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_1_sclk_ang_av_req.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      CK_TYPE                 = 1
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_1_sclk_ang_noav_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 1
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'NO'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_rfilter1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 0.01 0.01 0.01 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_rfilter2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 1.0 0.00297 0.004 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_tabcmt.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good_with_tabs.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_empcmt.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good_empty.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_timecor.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 2.013
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_sclk888.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_888.tsc'
      FRAMES_FILE_NAME        = 'fk_good_ck_sclk_888.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_fsclk999.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      MAKE_FAKE_SCLK          = 'sclk_fake_999.tsc'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_fsclk888.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      MAKE_FAKE_SCLK          = 'sclk_fake_888.tsc'
      FRAMES_FILE_NAME        = 'fk_good_ck_sclk_888.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_dsmpl.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.001
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_tol1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 1.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_tol50.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 50.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_maav_tol1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 1.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_maav_tol50.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 50.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_mana_tol1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP/NO AVERAGING'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 1.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_mana_tol50.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP/NO AVERAGING'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 50.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_axes123.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 1, 2, 3 )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_inst.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'INSTRUMENT'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_offsetdeg.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( -30.0, 10.0, 120.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      if ( $file eq "setup_good_3_sclk_ang_av_offsetrad.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( -0.5235987756, 0.1745329252, 2.0943951024 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'RADIANS'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      if ( $file eq "setup_good_3_sclk_ang_av_offset123.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( -0.5235987756, 0.1745329252, 2.0943951024 )
      OFFSET_ROTATION_AXES    = ( 1, 2, 3 )
      OFFSET_ROTATION_UNITS   = 'RADIANS'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_av_body.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'Z' 'Y' 'X' )
      EULER_ROTATIONS_TYPE    = 'BODY'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_angrad_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'RADIANS'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_noav_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'NO'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_dsclk_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'DSCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_et_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'ET'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_ticks_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'TICKS'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_utc_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'UTC'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_sclk_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_avg_sclk_rates.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999_average_rate.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_dsclk_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'DSCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_et_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'ET'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_ticks_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'TICKS'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_utc_ang_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'UTC'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_squat_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'SPICE QUATERNIONS'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_squat_av_qfilter.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'SPICE QUATERNIONS'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_mquat_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'MSOP QUATERNIONS'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_mat_av_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'MATRICES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_mat_av_req.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      CK_TYPE                 = 3
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'MATRICES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_maav_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_3_sclk_ang_mana_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP/NO AVERAGING'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_sclk_ang_maav_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_sclk_ang_mana_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP/NO AVERAGING'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_sclk_ang_mana_tol1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP/NO AVERAGING'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 1.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_good_2_sclk_ang_mana_tol50.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP/NO AVERAGING'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 50.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
      DUMP_OUTPUT_CK          = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_empty.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_lsk.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_sclk.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_two_sclks.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      MAKE_FAKE_SCLK          = 'sclk_fake_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_ck_type.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_inst_id.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_ref_frame.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_rate_flag.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_time_type.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_data_type.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_ang_units.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_rot_order.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_offset_axes.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_offset_units.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_producer.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_lsk_nonexistent.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'no_lsk'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_nonexistent.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'no_sclk'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_fk_nonexistent.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'no_fk'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_ck_type_4.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'no_comments'
      CK_TYPE                 = 4
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_ck_id_positive.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = 999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_frame_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'UNKNOWN_FRAME'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rate_flag_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'NO_RATES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_quat_threshold_neg.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = -0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_quat_threshold_zero.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_quat_threshold_big.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 1.1
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rate_threshold_neg.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( -1.0 1.0 1.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rate_threshold_zero.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 1.0 0.0 1.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rate_threshold_two.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 1.0 1.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rate_threshold_four.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 1.0 1.0 1.0 1.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_time_type_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'MINUTES'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_data_type_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'NUMBERS'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_angle_units_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'ARCSECONDS'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rotation_order_two.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rotation_order_four.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' 'X' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rotation_order_mixed.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' '3' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rotation_order_not_xyz.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'A' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rotation_order_not_123.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 1 2 4 )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rotation_type_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'UNIVERSE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_rate_frame_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'SYSTEM'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_angles_two.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_angles_four.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_axes_two.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_axes_four.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' 'X' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_axes_mixed.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' '3' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_axes_not_xyz.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'A' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_axes_not_123.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 1, 2, 4 )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_offset_units_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'ARCSECONDS'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_down_sample_neg.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = -0.01
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_inlude_table_unknown.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'MAYBE'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_misformatted_lsk.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = lsk_good.tls
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_misformatted_order.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 1 )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_misformatted_ck_type.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 1, 2, or 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_empty_lsk.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_bad_empty.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_empty_sclk.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_empty.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_empty_fk.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_bad_empty.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'CK999_REFERENCE'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_not_type_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_type_ne_1.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'DSCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_one_field.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_one_field.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'DSCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_one_moduli.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_one_moduli.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'DSCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_one_offset.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_one_offset.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'DSCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_no_coeffs.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_no_coeffs.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'ET'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_no_moduli.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_no_moduli.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'ET'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_sclk_zero_moduli.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_bad_999_zero_moduli.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'ET'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_make_rates_na_ck1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 1
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP/NO AVERAGING'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_make_rates_av_ck1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 1
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'MAKE UP'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_existing_fake_sclk.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      MAKE_FAKE_SCLK          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_no_av_ck2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'comments_good.txt'
      CK_TYPE                 = 2
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'NO'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "setup_bad_nonexistent_comments.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
KPL/SCLK
\\begindata
      LSK_FILE_NAME           = 'lsk_good.tls'
      SCLK_FILE_NAME          = 'sclk_good_999.tsc'
      FRAMES_FILE_NAME        = 'fk_good.tf'
      INTERNAL_FILE_NAME      = 'test'
      COMMENTS_FILE_NAME      = 'no_comments'
      CK_TYPE                 = 3
      CK_SEGMENT_ID           = 'test'
      INSTRUMENT_ID           = -999000
      REFERENCE_FRAME_NAME    = 'J2000'
      ANGULAR_RATE_PRESENT    = 'YES'
      QUATERNION_NORM_ERROR   = 0.0001
      ANGULAR_RATE_THRESHOLD  = ( 10.0 10.0 10.0 )
      MAXIMUM_VALID_INTERVAL  = 450.0
      TIME_CORRECTION         = 0.0
      INPUT_TIME_TYPE         = 'SCLK'
      INPUT_DATA_TYPE         = 'EULER ANGLES'
      EULER_ANGLE_UNITS       = 'DEGREES'
      EULER_ROTATIONS_ORDER   = ( 'X' 'Y' 'Z' )
      EULER_ROTATIONS_TYPE    = 'SPACE'
      ANGULAR_RATE_FRAME      = 'REFERENCE'
      OFFSET_ROTATION_ANGLES  = ( 0.0, 0.0, 0.0 )
      OFFSET_ROTATION_AXES    = ( 'X' 'Y' 'Z' )
      OFFSET_ROTATION_UNITS   = 'DEGREES'
      DOWN_SAMPLE_TOLERANCE   = 0.0
      INCLUDE_INTERVAL_TABLE  = 'YES'
      PRODUCER_ID             = 'BVS/NAIF'
\\begintext
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_empty.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_blank_line_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;



EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_blank_line_leading.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;

  0.0   0. 0 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_blank_line_trailing.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0

EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_blank_line_middle.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0

270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_delimited_tab.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
0.0\t0.\t0\t0\t0.5\t0\t0
180.0\t90.\t0\t0\t2.0\t0\t0
225.0\t180.\t0\t0\t2.0\t0\t0
270.0\t270.\t0\t0\t0.5\t0\t0
450.0\t0.\t0\t0\t0.5\t0\t0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_delimited_comma.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
0.0,0.,0,0,0.5,0,0
180.0,90.,0,0,2.0,0,0
225.0,180.,0,0,2.0,0,0
270.0,270.,0,0,0.5,0,0
450.0,0.,0,0,0.5,0,0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_time_numeric.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
time    0. 0 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_time_utc.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
YYYY-01-01T11:58:55.816   0. 0 0 0.5 0 0
2000-01-01T12:01:55.816  90. 0 0 2.0 0 0
2000-01-01T12:02:40.816 180. 0 0 2.0 0 0
2000-01-01T12:03:25.816 270. 0 0 0.5 0 0
2000-01-01T12:06:25.816   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_time_numeric_stop.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0 time   0. 0 0 0.5 0 0
180.0 225.0  90. 0 0 2.0 0 0
225.0 270.0 180. 0 0 2.0 0 0
270.0 450.0 270. 0 0 0.5 0 0
450.0 451.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_time_utc_stop.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
2000-01-01T11:58:55.816 2000-MM-01T12:01:55.816   0. 0 0 0.5 0 0
2000-01-01T12:01:55.816 2000-01-01T12:02:40.816  90. 0 0 2.0 0 0
2000-01-01T12:02:40.816 2000-01-01T12:03:25.816 180. 0 0 2.0 0 0
2000-01-01T12:03:25.816 2000-01-01T12:06:25.816 270. 0 0 0.5 0 0
2000-01-01T12:06:25.816 2000-01-01T12:06:26.816   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_angle_numeric_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0.a 0 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_angle_numeric_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0b 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_angle_numeric_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0c 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_angle_too_few_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0.
180.0  90. 0 0
225.0 180. 0 0
270.0 270. 0 0
450.0   0. 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_angle_too_few_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0
180.0  90. 0 0
225.0 180. 0 0
270.0 270. 0 0
450.0   0. 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_rate_numeric_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5a 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_rate_numeric_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5 0b 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_rate_numeric_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5 0 0c
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_rate_too_few_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_rate_too_few_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
270.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_squat_numeric_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000a  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_squat_numeric_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000b  0.00000000  0.00000000 0.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_squat_numeric_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000  0.00000000c  0.00000000 0.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_squat_numeric_4.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000  0.00000000  0.00000000g 0.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_squat_too_few_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_squat_too_few_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_squat_too_few_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000  0.00000000
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mquat_numeric_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000a  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mquat_numeric_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000  0.00000000b  0.00000000  1.00000000 0.00872664625997 0 0
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mquat_numeric_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000  0.00000000  0.00000000c  1.00000000 0.00872664625997 0 0
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mquat_numeric_4.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000  0.00000000  0.00000000  1.00000000g 0.00872664625997 0 0
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mquat_too_few_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mquat_too_few_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000  0.00000000
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mquat_too_few_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  0.00000000  0.00000000  0.00000000
180.0  0.70710678  0.00000000  0.00000000  0.70710678 0.03490658503989 0 0
225.0  1.00000000  0.00000000  0.00000000  0.00000000 0.03490658503989 0 0
270.0 -0.70710678  0.00000000  0.00000000  0.70710678 0.00872664625997 0 0
450.0  0.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0a  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0b  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0c  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_4.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0g  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_5.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0h  0.0  0.0  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_6.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0i  0.0  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_7.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0j  0.0  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_8.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0k  1.0  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_numeric_9.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0l  0.00872664625997 0 0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_1.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_2.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_3.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_4.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_5.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_6.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_7.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_mat_too_few_8.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0
180.0  1.0  0.0  0.0  0.0  0.0  1.0  0.0 -1.0  0.0  0.03490658503989 0 0
225.0  1.0  0.0  0.0  0.0 -1.0  0.0  0.0  0.0 -1.0  0.03490658503989 0 0
270.0  1.0  0.0  0.0  0.0  0.0 -1.0  0.0  1.0  0.0  0.00872664625997 0 0
450.0  1.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  1.0  0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_duplicate_times.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0   0. 0 0 0.5 0 0
180.0  90. 0 0 2.0 0 0
225.0 180. 0 0 2.0 0 0
225.0 270. 0 0 0.5 0 0
450.0   0. 0 0 0.5 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_quats_nonunit_all.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  1.00000000 0.03490658503989 0 0
225.0  0.00000000 -1.00000000  0.00000000  1.00000000 0.03490658503989 0 0
270.0  0.70710678  0.70710678  0.00000000  1.00000000 0.00872664625997 0 0
450.0  1.00000000  0.00000000  0.00000000  1.00000000 0.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }



      #----------------------------------------------------------------------
      if ( $file eq "input_bad_too_large_avs.txt" ) {
        open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
        print OUTPUT <<EndBlock;
  0.0  1.00000000  0.00000000  0.00000000  0.00000000 100.00872664625997 0 0
180.0  0.70710678 -0.70710678  0.00000000  0.00000000 0.03490658503989 10.1 0
225.0  0.00000000 -1.00000000  0.00000000  0.00000000 0.03490658503989 0 -11
270.0  0.70710678  0.70710678  0.00000000  0.00000000 0.00872664625997 -10.00001 0
450.0  1.00000000  0.00000000  0.00000000  0.00000000 10.00872664625997 0 0
EndBlock
        close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
      }

    }

  }

}
